from __future__ import annotations

import pytest
from tests.test_lib import parse_build_compare_editor

from mercury_engine_data_structures import dread_data, samus_returns_data
from mercury_engine_data_structures.formats.bcskla import Bcskla

sr_missing = [
    "actors/characters/alpha/animations/attacksynchrofail2.bcskla",
    "actors/characters/alpha/animations/turn.bcskla",
    "actors/characters/arachnus/animations/attackfiresplashfast.bcskla",
    "actors/characters/arachnus/animations/impact.bcskla",
    "actors/characters/arachnusball/animations/jumpback.bcskla",
    "actors/characters/arachnusball/animations/run.bcskla",
    "actors/characters/arachnusball/animations/turn.bcskla",
    "actors/characters/arachnusball/animations/walkback.bcskla",
    "actors/characters/blobthrower/animations/death.bcskla",
    "actors/characters/gamma/animations/death.bcskla",
    "actors/characters/gamma/animations/fallimpact.bcskla",
    "actors/characters/gamma/animations/spawn33.bcskla",
    "actors/characters/gamma/animations/turn.bcskla",
    "actors/characters/gamma/animations/unfreezefailend.bcskla",
    "actors/characters/gawron/animations/spawn.bcskla",
    "actors/characters/glowfly/animations/crazy.bcskla",
    "actors/characters/glowfly/animations/death.bcskla",
    "actors/characters/gravitt/animations/leftblockattack.bcskla",
    "actors/characters/gravitt/animations/rightblockattack.bcskla",
    "actors/characters/gullugg/animations/attackleft2relax.bcskla",
    "actors/characters/gullugg/animations/attackright2relax.bcskla",
    "actors/characters/hornoad/animations/frozen.bcskla",
    "actors/characters/hornoad/animations/unfreeze.bcskla",
    "actors/characters/manicminerbot/animations/relax.bcskla",
    "actors/characters/manicminerbothidden/animations/relax.bcskla",
    "actors/characters/moheek/animations/death.bcskla",
    "actors/characters/moto/animations/run.bcskla",
    "actors/characters/queen/animations/crazy.bcskla",
    "actors/characters/queen/animations/death.bcskla",
    "actors/characters/queen/animations/impact.bcskla",
    "actors/characters/queen/animations/stagger.bcskla",
    "actors/characters/queen/animations/walkback.bcskla",
    "actors/characters/ramulken/animations/rightcrazyend.bcskla",
    "actors/characters/ridley/animations/attackadvancedtailprick2.bcskla",
    "actors/characters/ridley/animations/attacktailprick1.bcskla",
    "actors/characters/ridley/animations/attacktailprick2.bcskla",
    "actors/characters/ridley/animations/attacktailprickend.bcskla",
    "actors/characters/ridley/animations/attacktailsweepend.bcskla",
    "actors/characters/ridley/animations/attacktailsweependwall.bcskla",
    "actors/characters/ridley/animations/grabridleysuccessend.bcskla",
    "actors/characters/ridley/animations/grabridleysuccessinit.bcskla",
    "actors/characters/ridley/animations/grabridleysuccessloop.bcskla",
    "actors/characters/ridley/animations/jumpback.bcskla",
    "actors/characters/samus/animations/block.bcskla",
    "actors/characters/samus/animations/blockback.bcskla",
    "actors/characters/samus/animations/blockcrouchbottom.bcskla",
    "actors/characters/samus/animations/blockcrouchtop.bcskla",
    "actors/characters/samus/animations/blockcrouchturnbottom.bcskla",
    "actors/characters/samus/animations/blockcrouchturntop.bcskla",
    "actors/characters/samus/animations/blockfall.bcskla",
    "actors/characters/samus/animations/blockfallbottom.bcskla",
    "actors/characters/samus/animations/blockfallend2runbottom.bcskla",
    "actors/characters/samus/animations/blockfallend2runtop.bcskla",
    "actors/characters/samus/animations/blockfallendbottom.bcskla",
    "actors/characters/samus/animations/blockfallendtop.bcskla",
    "actors/characters/samus/animations/blockfalltop.bcskla",
    "actors/characters/samus/animations/blockhang.bcskla",
    "actors/characters/samus/animations/blockhangbottom.bcskla",
    "actors/characters/samus/animations/blockhangend.bcskla",
    "actors/characters/samus/animations/blockhangendbottom.bcskla",
    "actors/characters/samus/animations/blockhangendtop.bcskla",
    "actors/characters/samus/animations/blockhangsuccess.bcskla",
    "actors/characters/samus/animations/blockhangtop.bcskla",
    "actors/characters/samus/animations/blockjump2fallbottom.bcskla",
    "actors/characters/samus/animations/blockjump2falltop.bcskla",
    "actors/characters/samus/animations/blockjumpbottom.bcskla",
    "actors/characters/samus/animations/blockjumpinitbottom.bcskla",
    "actors/characters/samus/animations/blockjumpinittop.bcskla",
    "actors/characters/samus/animations/blockjumptop.bcskla",
    "actors/characters/samus/animations/blockrunendbottom.bcskla",
    "actors/characters/samus/animations/blockrunendtop.bcskla",
    "actors/characters/samus/animations/borderfront.bcskla",
    "actors/characters/samus/animations/borderfrontdown.bcskla",
    "actors/characters/samus/animations/borderfrontdownbottom.bcskla",
    "actors/characters/samus/animations/borderfrontup.bcskla",
    "actors/characters/samus/animations/borderfrontupbottom.bcskla",
    "actors/characters/samus/animations/borderrecoilfront.bcskla",
    "actors/characters/samus/animations/borderrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/borderrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/borderrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/borderrecoilfrontup.bcskla",
    "actors/characters/samus/animations/borderrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/borderrecoilup.bcskla",
    "actors/characters/samus/animations/borderrecoilupbottom.bcskla",
    "actors/characters/samus/animations/borderup.bcskla",
    "actors/characters/samus/animations/borderupbottom.bcskla",
    "actors/characters/samus/animations/chargecrouch.bcskla",
    "actors/characters/samus/animations/chargecrouchbottom.bcskla",
    "actors/characters/samus/animations/chargecrouchinit.bcskla",
    "actors/characters/samus/animations/chargecrouchinitbottom.bcskla",
    "actors/characters/samus/animations/chargecrouchinittop.bcskla",
    "actors/characters/samus/animations/chargecrouchlaunch.bcskla",
    "actors/characters/samus/animations/chargecrouchlaunchbottom.bcskla",
    "actors/characters/samus/animations/chargecrouchlaunchtop.bcskla",
    "actors/characters/samus/animations/chargecrouchtop.bcskla",
    "actors/characters/samus/animations/chargecrouchturn.bcskla",
    "actors/characters/samus/animations/chargecrouchturnbottom.bcskla",
    "actors/characters/samus/animations/chargecrouchturnend.bcskla",
    "actors/characters/samus/animations/chargecrouchturnendlaunch.bcskla",
    "actors/characters/samus/animations/chargecrouchturnlaunch.bcskla",
    "actors/characters/samus/animations/chargecrouchturnlaunchbottom.bcskla",
    "actors/characters/samus/animations/chargecrouchturnlaunchtop.bcskla",
    "actors/characters/samus/animations/chargecrouchturntop.bcskla",
    "actors/characters/samus/animations/chargefall.bcskla",
    "actors/characters/samus/animations/chargefallbottom.bcskla",
    "actors/characters/samus/animations/chargefallend.bcskla",
    "actors/characters/samus/animations/chargefallend2run.bcskla",
    "actors/characters/samus/animations/chargefallend2runbottom.bcskla",
    "actors/characters/samus/animations/chargefallend2runtop.bcskla",
    "actors/characters/samus/animations/chargefallend2walk.bcskla",
    "actors/characters/samus/animations/chargefallend2walkbottom.bcskla",
    "actors/characters/samus/animations/chargefallend2walktop.bcskla",
    "actors/characters/samus/animations/chargefallendbottom.bcskla",
    "actors/characters/samus/animations/chargefallendlaunch.bcskla",
    "actors/characters/samus/animations/chargefallendlaunchbottom.bcskla",
    "actors/characters/samus/animations/chargefallendlaunchtop.bcskla",
    "actors/characters/samus/animations/chargefallendtop.bcskla",
    "actors/characters/samus/animations/chargefalllaunch.bcskla",
    "actors/characters/samus/animations/chargefalllaunchbottom.bcskla",
    "actors/characters/samus/animations/chargefalllaunchtop.bcskla",
    "actors/characters/samus/animations/chargefalltop.bcskla",
    "actors/characters/samus/animations/chargejump.bcskla",
    "actors/characters/samus/animations/chargejump2fall.bcskla",
    "actors/characters/samus/animations/chargejump2fallbottom.bcskla",
    "actors/characters/samus/animations/chargejump2fallinit.bcskla",
    "actors/characters/samus/animations/chargejump2fallinitbottom.bcskla",
    "actors/characters/samus/animations/chargejump2fallinittop.bcskla",
    "actors/characters/samus/animations/chargejump2falllaunch.bcskla",
    "actors/characters/samus/animations/chargejump2falllaunchbottom.bcskla",
    "actors/characters/samus/animations/chargejump2falllaunchtop.bcskla",
    "actors/characters/samus/animations/chargejump2falltop.bcskla",
    "actors/characters/samus/animations/chargejumpbottom.bcskla",
    "actors/characters/samus/animations/chargejumpinit.bcskla",
    "actors/characters/samus/animations/chargejumpinitbottom.bcskla",
    "actors/characters/samus/animations/chargejumpinitlaunch.bcskla",
    "actors/characters/samus/animations/chargejumpinitlaunchbottom.bcskla",
    "actors/characters/samus/animations/chargejumpinitlaunchtop.bcskla",
    "actors/characters/samus/animations/chargejumpinittop.bcskla",
    "actors/characters/samus/animations/chargejumplaunch.bcskla",
    "actors/characters/samus/animations/chargejumplaunchbottom.bcskla",
    "actors/characters/samus/animations/chargejumplaunchtop.bcskla",
    "actors/characters/samus/animations/chargejumptop.bcskla",
    "actors/characters/samus/animations/chargerelax.bcskla",
    "actors/characters/samus/animations/chargerelaxbottom.bcskla",
    "actors/characters/samus/animations/chargerelaxend.bcskla",
    "actors/characters/samus/animations/chargerelaxendbottom.bcskla",
    "actors/characters/samus/animations/chargerelaxendtop.bcskla",
    "actors/characters/samus/animations/chargerelaxinit.bcskla",
    "actors/characters/samus/animations/chargerelaxinitbottom.bcskla",
    "actors/characters/samus/animations/chargerelaxinittop.bcskla",
    "actors/characters/samus/animations/chargerelaxlaunch.bcskla",
    "actors/characters/samus/animations/chargerelaxlaunchbottom.bcskla",
    "actors/characters/samus/animations/chargerelaxlaunchtop.bcskla",
    "actors/characters/samus/animations/chargerelaxtop.bcskla",
    "actors/characters/samus/animations/chargerelaxturn.bcskla",
    "actors/characters/samus/animations/chargerelaxturnbottom.bcskla",
    "actors/characters/samus/animations/chargerelaxturnend.bcskla",
    "actors/characters/samus/animations/chargerelaxturnendbottom.bcskla",
    "actors/characters/samus/animations/chargerelaxturnendtop.bcskla",
    "actors/characters/samus/animations/chargerelaxturntop.bcskla",
    "actors/characters/samus/animations/chargerun.bcskla",
    "actors/characters/samus/animations/chargerunbottom.bcskla",
    "actors/characters/samus/animations/chargerunend.bcskla",
    "actors/characters/samus/animations/chargerunendbottom.bcskla",
    "actors/characters/samus/animations/chargerunendlaunch.bcskla",
    "actors/characters/samus/animations/chargerunendlaunchbottom.bcskla",
    "actors/characters/samus/animations/chargerunendlaunchtop.bcskla",
    "actors/characters/samus/animations/chargerunendtop.bcskla",
    "actors/characters/samus/animations/chargeruninit.bcskla",
    "actors/characters/samus/animations/chargerunlaunch.bcskla",
    "actors/characters/samus/animations/chargeruntop.bcskla",
    "actors/characters/samus/animations/chargeruntopbottom.bcskla",
    "actors/characters/samus/animations/chargeruntoptop.bcskla",
    "actors/characters/samus/animations/chargerunturn.bcskla",
    "actors/characters/samus/animations/chargerunturnbottom.bcskla",
    "actors/characters/samus/animations/chargerunturnend.bcskla",
    "actors/characters/samus/animations/chargerunturnend2relax.bcskla",
    "actors/characters/samus/animations/chargerunturnend2relaxbottom.bcskla",
    "actors/characters/samus/animations/chargerunturnend2relaxtop.bcskla",
    "actors/characters/samus/animations/chargerunturnendbottom.bcskla",
    "actors/characters/samus/animations/chargerunturnendtop.bcskla",
    "actors/characters/samus/animations/chargerunturntop.bcskla",
    "actors/characters/samus/animations/chargetop.bcskla",
    "actors/characters/samus/animations/checkingdna.bcskla",
    "actors/characters/samus/animations/checkingdnatowaiting.bcskla",
    "actors/characters/samus/animations/climb1m2mb.bcskla",
    "actors/characters/samus/animations/climb2m2mb.bcskla",
    "actors/characters/samus/animations/crouchanalog.bcskla",
    "actors/characters/samus/animations/crouchanalogbottom.bcskla",
    "actors/characters/samus/animations/crouchanaloginvert.bcskla",
    "actors/characters/samus/animations/crouchanaloginvertbottom.bcskla",
    "actors/characters/samus/animations/crouchanaloginvertrecoil.bcskla",
    "actors/characters/samus/animations/crouchanaloginvertrecoilbottom.bcskla",
    "actors/characters/samus/animations/crouchanaloginvertrecoiltop.bcskla",
    "actors/characters/samus/animations/crouchanaloginverttop.bcskla",
    "actors/characters/samus/animations/crouchanalogrecoil.bcskla",
    "actors/characters/samus/animations/crouchanalogrecoilbottom.bcskla",
    "actors/characters/samus/animations/crouchanalogrecoiltop.bcskla",
    "actors/characters/samus/animations/crouchanalogtop.bcskla",
    "actors/characters/samus/animations/crouchanalogwide.bcskla",
    "actors/characters/samus/animations/crouchanalogwideinvert.bcskla",
    "actors/characters/samus/animations/crouchanalogwideinvertrecoil.bcskla",
    "actors/characters/samus/animations/crouchanalogwiderecoil.bcskla",
    "actors/characters/samus/animations/crouchfront.bcskla",
    "actors/characters/samus/animations/crouchfront2mb.bcskla",
    "actors/characters/samus/animations/crouchfrontdown.bcskla",
    "actors/characters/samus/animations/crouchfrontdown2mb.bcskla",
    "actors/characters/samus/animations/crouchfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchfrontpose.bcskla",
    "actors/characters/samus/animations/crouchfrontup.bcskla",
    "actors/characters/samus/animations/crouchfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchlaunchbotton.bcskla",
    "actors/characters/samus/animations/crouchlaunchbottonbottom.bcskla",
    "actors/characters/samus/animations/crouchlaunchbottontop.bcskla",
    "actors/characters/samus/animations/crouchlaunchtop.bcskla",
    "actors/characters/samus/animations/crouchlaunchtopbottom.bcskla",
    "actors/characters/samus/animations/crouchlaunchtoptop.bcskla",
    "actors/characters/samus/animations/crouchrecoilfront.bcskla",
    "actors/characters/samus/animations/crouchrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/crouchrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/crouchrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchrecoilfronttop.bcskla",
    "actors/characters/samus/animations/crouchrecoilfrontup.bcskla",
    "actors/characters/samus/animations/crouchrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchrecoilup.bcskla",
    "actors/characters/samus/animations/crouchrecoilupbottom.bcskla",
    "actors/characters/samus/animations/crouchrecoiluptop.bcskla",
    "actors/characters/samus/animations/crouchshotendfront.bcskla",
    "actors/characters/samus/animations/crouchshotendfrontdown.bcskla",
    "actors/characters/samus/animations/crouchshotendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchshotendfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchshotendfrontup.bcskla",
    "actors/characters/samus/animations/crouchshotendfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotendfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchshotendup.bcskla",
    "actors/characters/samus/animations/crouchshotendupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotenduptop.bcskla",
    "actors/characters/samus/animations/crouchshotfirefront.bcskla",
    "actors/characters/samus/animations/crouchshotfirefrontdown.bcskla",
    "actors/characters/samus/animations/crouchshotfirefrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchshotfirefrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchshotfirefrontup.bcskla",
    "actors/characters/samus/animations/crouchshotfirefrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotfirefrontuptop.bcskla",
    "actors/characters/samus/animations/crouchshotfireup.bcskla",
    "actors/characters/samus/animations/crouchshotfireupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotfireuptop.bcskla",
    "actors/characters/samus/animations/crouchshotfront.bcskla",
    "actors/characters/samus/animations/crouchshotfrontdown.bcskla",
    "actors/characters/samus/animations/crouchshotfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchshotfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchshotfrontpose.bcskla",
    "actors/characters/samus/animations/crouchshotfrontup.bcskla",
    "actors/characters/samus/animations/crouchshotfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchshotinitfront.bcskla",
    "actors/characters/samus/animations/crouchshotinitfrontdown.bcskla",
    "actors/characters/samus/animations/crouchshotinitfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchshotinitfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchshotinitfrontup.bcskla",
    "actors/characters/samus/animations/crouchshotinitfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotinitfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchshotinitup.bcskla",
    "actors/characters/samus/animations/crouchshotinitupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotinituptop.bcskla",
    "actors/characters/samus/animations/crouchshotup.bcskla",
    "actors/characters/samus/animations/crouchshotupbottom.bcskla",
    "actors/characters/samus/animations/crouchshotuptop.bcskla",
    "actors/characters/samus/animations/crouchturnendfront.bcskla",
    "actors/characters/samus/animations/crouchturnendfrontdown.bcskla",
    "actors/characters/samus/animations/crouchturnendfrontup.bcskla",
    "actors/characters/samus/animations/crouchturnendrecoilfront.bcskla",
    "actors/characters/samus/animations/crouchturnendrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/crouchturnendrecoilfrontup.bcskla",
    "actors/characters/samus/animations/crouchturnendrecoilup.bcskla",
    "actors/characters/samus/animations/crouchturnendup.bcskla",
    "actors/characters/samus/animations/crouchturnfront.bcskla",
    "actors/characters/samus/animations/crouchturnfrontdown.bcskla",
    "actors/characters/samus/animations/crouchturnfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchturnfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchturnfrontup.bcskla",
    "actors/characters/samus/animations/crouchturnfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchturnfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfront.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfrontup.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilup.bcskla",
    "actors/characters/samus/animations/crouchturnrecoilupbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrecoiluptop.bcskla",
    "actors/characters/samus/animations/crouchturnrwfront.bcskla",
    "actors/characters/samus/animations/crouchturnrwfrontbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrwfrontdown.bcskla",
    "actors/characters/samus/animations/crouchturnrwfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrwfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchturnrwfronttop.bcskla",
    "actors/characters/samus/animations/crouchturnrwfrontup.bcskla",
    "actors/characters/samus/animations/crouchturnrwfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrwfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfront.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfronttop.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfrontup.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/crouchturnrwrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/crouchturnup.bcskla",
    "actors/characters/samus/animations/crouchturnupbottom.bcskla",
    "actors/characters/samus/animations/crouchturnuptop.bcskla",
    "actors/characters/samus/animations/crouchup.bcskla",
    "actors/characters/samus/animations/crouchupbottom.bcskla",
    "actors/characters/samus/animations/crouchuptop.bcskla",
    "actors/characters/samus/animations/death.bcskla",
    "actors/characters/samus/animations/deathinit.bcskla",
    "actors/characters/samus/animations/fallanalog.bcskla",
    "actors/characters/samus/animations/fallanaloginvert.bcskla",
    "actors/characters/samus/animations/fallanaloginvertrecoil.bcskla",
    "actors/characters/samus/animations/fallanalogrecoil.bcskla",
    "actors/characters/samus/animations/falldown.bcskla",
    "actors/characters/samus/animations/falldown2mb.bcskla",
    "actors/characters/samus/animations/falldownbottom.bcskla",
    "actors/characters/samus/animations/fallend2run.bcskla",
    "actors/characters/samus/animations/fallend2runbottom.bcskla",
    "actors/characters/samus/animations/fallend2runfront.bcskla",
    "actors/characters/samus/animations/fallend2runfrontdown.bcskla",
    "actors/characters/samus/animations/fallend2runfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallend2runfrontup.bcskla",
    "actors/characters/samus/animations/fallend2runfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallend2runrecoilfront.bcskla",
    "actors/characters/samus/animations/fallend2runrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/fallend2runrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/fallend2runrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallend2runrecoilfrontup.bcskla",
    "actors/characters/samus/animations/fallend2runrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallend2walkfront.bcskla",
    "actors/characters/samus/animations/fallend2walkfrontdown.bcskla",
    "actors/characters/samus/animations/fallend2walkfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallend2walkfrontup.bcskla",
    "actors/characters/samus/animations/fallend2walkfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallend2walkrecoilfront.bcskla",
    "actors/characters/samus/animations/fallend2walkrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/fallend2walkrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/fallend2walkrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallend2walkrecoilfrontup.bcskla",
    "actors/characters/samus/animations/fallend2walkrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallendfront.bcskla",
    "actors/characters/samus/animations/fallendfrontdown.bcskla",
    "actors/characters/samus/animations/fallendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallendfrontup.bcskla",
    "actors/characters/samus/animations/fallendfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallendrecoilfront.bcskla",
    "actors/characters/samus/animations/fallendrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/fallendrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/fallendrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallendrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/fallendrecoilfronttop.bcskla",
    "actors/characters/samus/animations/fallendrecoilfrontup.bcskla",
    "actors/characters/samus/animations/fallendrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallendrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/fallendrecoilup.bcskla",
    "actors/characters/samus/animations/fallendrecoilupbottom.bcskla",
    "actors/characters/samus/animations/fallendrecoiluptop.bcskla",
    "actors/characters/samus/animations/fallendup.bcskla",
    "actors/characters/samus/animations/fallendupbottom.bcskla",
    "actors/characters/samus/animations/fallfront.bcskla",
    "actors/characters/samus/animations/fallfrontdown.bcskla",
    "actors/characters/samus/animations/fallfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallfrontup.bcskla",
    "actors/characters/samus/animations/fallfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallhighendfront.bcskla",
    "actors/characters/samus/animations/fallhighendfrontdown.bcskla",
    "actors/characters/samus/animations/fallhighendfrontup.bcskla",
    "actors/characters/samus/animations/fallhighendup.bcskla",
    "actors/characters/samus/animations/fallrecoildown.bcskla",
    "actors/characters/samus/animations/fallrecoildownbottom.bcskla",
    "actors/characters/samus/animations/fallrecoilfront.bcskla",
    "actors/characters/samus/animations/fallrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/fallrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/fallrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/fallrecoilfrontup.bcskla",
    "actors/characters/samus/animations/fallrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/fallrecoilup.bcskla",
    "actors/characters/samus/animations/fallrecoilupbottom.bcskla",
    "actors/characters/samus/animations/fallup.bcskla",
    "actors/characters/samus/animations/fallupbottom.bcskla",
    "actors/characters/samus/animations/grabmanicminerbotsamusend.bcskla",
    "actors/characters/samus/animations/grabmanicminerbotsamusleft.bcskla",
    "actors/characters/samus/animations/grabmanicminerbotsamusmid.bcskla",
    "actors/characters/samus/animations/grabmanicminerbotsamusright.bcskla",
    "actors/characters/samus/animations/grabridleysuccessend.bcskla",
    "actors/characters/samus/animations/grabridleysuccessendbottom.bcskla",
    "actors/characters/samus/animations/grabridleysuccessendtop.bcskla",
    "actors/characters/samus/animations/grabridleysuccessinit.bcskla",
    "actors/characters/samus/animations/grabridleysuccessinitbottom.bcskla",
    "actors/characters/samus/animations/grabridleysuccessinittop.bcskla",
    "actors/characters/samus/animations/grabridleysuccessleftend.bcskla",
    "actors/characters/samus/animations/grabridleysuccessleftinit.bcskla",
    "actors/characters/samus/animations/grabridleysuccessleftloop.bcskla",
    "actors/characters/samus/animations/grabridleysuccessloop.bcskla",
    "actors/characters/samus/animations/grabridleysuccessloopbottom.bcskla",
    "actors/characters/samus/animations/grabridleysuccesslooptop.bcskla",
    "actors/characters/samus/animations/grabridleysuccessrightend.bcskla",
    "actors/characters/samus/animations/grabridleysuccessrightinit.bcskla",
    "actors/characters/samus/animations/grabridleysuccessrightloop.bcskla",
    "actors/characters/samus/animations/grabsamusalpha.bcskla",
    "actors/characters/samus/animations/grabsamusalpharecoil.bcskla",
    "actors/characters/samus/animations/grabsamusalpharecoilbottom.bcskla",
    "actors/characters/samus/animations/grabsamusgamma.bcskla",
    "actors/characters/samus/animations/grabsamusgammarecoil.bcskla",
    "actors/characters/samus/animations/grabsamusgammarecoilbottom.bcskla",
    "actors/characters/samus/animations/grabsamusomega.bcskla",
    "actors/characters/samus/animations/grabsamusomegarecoil.bcskla",
    "actors/characters/samus/animations/grabsamusomegarecoilbottom.bcskla",
    "actors/characters/samus/animations/grabsamusridley.bcskla",
    "actors/characters/samus/animations/grabsamusridleyrecoil.bcskla",
    "actors/characters/samus/animations/grabsamusridleyrecoilbottom.bcskla",
    "actors/characters/samus/animations/grabsamuszeta.bcskla",
    "actors/characters/samus/animations/grabsamuszetarecoil.bcskla",
    "actors/characters/samus/animations/grabsamuszetarecoilbottom.bcskla",
    "actors/characters/samus/animations/grapple2fall.bcskla",
    "actors/characters/samus/animations/grapplebackward2forward.bcskla",
    "actors/characters/samus/animations/grapplebrake.bcskla",
    "actors/characters/samus/animations/grappledownbottom.bcskla",
    "actors/characters/samus/animations/grappledowntop.bcskla",
    "actors/characters/samus/animations/grappledragbottom.bcskla",
    "actors/characters/samus/animations/grappledragbottonbottom.bcskla",
    "actors/characters/samus/animations/grappledragbottontop.bcskla",
    "actors/characters/samus/animations/grappledragdown.bcskla",
    "actors/characters/samus/animations/grappledragdowntop.bcskla",
    "actors/characters/samus/animations/grappledragdowntopbottom.bcskla",
    "actors/characters/samus/animations/grappledragdowntoptop.bcskla",
    "actors/characters/samus/animations/grappledragfront.bcskla",
    "actors/characters/samus/animations/grappledragfrontbottom.bcskla",
    "actors/characters/samus/animations/grappledragfrontdown.bcskla",
    "actors/characters/samus/animations/grappledragfrontdowntop.bcskla",
    "actors/characters/samus/animations/grappledragfrontfrontup.bcskla",
    "actors/characters/samus/animations/grappledragfrontfrontupbottom.bcskla",
    "actors/characters/samus/animations/grappledragfrontfrontuptop.bcskla",
    "actors/characters/samus/animations/grappledragfronttop.bcskla",
    "actors/characters/samus/animations/grappledragfrontup.bcskla",
    "actors/characters/samus/animations/grappledragfrontupbottom.bcskla",
    "actors/characters/samus/animations/grappledragfrontuptop.bcskla",
    "actors/characters/samus/animations/grappledragfrontupup.bcskla",
    "actors/characters/samus/animations/grappledragfrontupupbottom.bcskla",
    "actors/characters/samus/animations/grappledragfrontupuptop.bcskla",
    "actors/characters/samus/animations/grappledragup.bcskla",
    "actors/characters/samus/animations/grappledragupbottom.bcskla",
    "actors/characters/samus/animations/grappledraguptop.bcskla",
    "actors/characters/samus/animations/grappledragwidedown.bcskla",
    "actors/characters/samus/animations/grappledragwidedownbottom.bcskla",
    "actors/characters/samus/animations/grappledragwidedowntop.bcskla",
    "actors/characters/samus/animations/grappledragwidefronfrontup.bcskla",
    "actors/characters/samus/animations/grappledragwidefront.bcskla",
    "actors/characters/samus/animations/grappledragwidefrontdown.bcskla",
    "actors/characters/samus/animations/grappledragwidefrontup.bcskla",
    "actors/characters/samus/animations/grappledragwidefrontupup.bcskla",
    "actors/characters/samus/animations/grappledragwideup.bcskla",
    "actors/characters/samus/animations/grappleendbackward.bcskla",
    "actors/characters/samus/animations/grappleendforward.bcskla",
    "actors/characters/samus/animations/grappleforward.bcskla",
    "actors/characters/samus/animations/grappleforward2backward.bcskla",
    "actors/characters/samus/animations/grappleforward2forward.bcskla",
    "actors/characters/samus/animations/grapplehang.bcskla",
    "actors/characters/samus/animations/grapplehanginit.bcskla",
    "actors/characters/samus/animations/grapplehanginitshort.bcskla",
    "actors/characters/samus/animations/grappleimpulse.bcskla",
    "actors/characters/samus/animations/grappleinit.bcskla",
    "actors/characters/samus/animations/grappleinitup.bcskla",
    "actors/characters/samus/animations/grappleinstantimpulse.bcskla",
    "actors/characters/samus/animations/grappleloop.bcskla",
    "actors/characters/samus/animations/grappleloop2forward.bcskla",
    "actors/characters/samus/animations/grappleloopend.bcskla",
    "actors/characters/samus/animations/grapplerelax.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfront.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontbottom.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontdown.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontdownbottom.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontdowntop.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontfrontup.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontfrontupbottom.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontfrontuptop.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfronttop.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontup.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontupbottom.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontuptop.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontupup.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontupupbottom.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragfrontupuptop.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragup.bcskla",
    "actors/characters/samus/animations/grapplerelaxdragupbottom.bcskla",
    "actors/characters/samus/animations/grapplerelaxdraguptop.bcskla",
    "actors/characters/samus/animations/grapplerelaxwidefront.bcskla",
    "actors/characters/samus/animations/grapplerelaxwidefrontdown.bcskla",
    "actors/characters/samus/animations/grapplerelaxwidefrontfrontup.bcskla",
    "actors/characters/samus/animations/grapplerelaxwidefrontup.bcskla",
    "actors/characters/samus/animations/grapplerelaxwidefrontupup.bcskla",
    "actors/characters/samus/animations/grapplerelaxwideup.bcskla",
    "actors/characters/samus/animations/grapplestartbackward.bcskla",
    "actors/characters/samus/animations/grapplestartbackwardbottom.bcskla",
    "actors/characters/samus/animations/grapplestartbackwardtop.bcskla",
    "actors/characters/samus/animations/grapplestartforward.bcskla",
    "actors/characters/samus/animations/grappleturn.bcskla",
    "actors/characters/samus/animations/grappleupbottom.bcskla",
    "actors/characters/samus/animations/grappleuptop.bcskla",
    "actors/characters/samus/animations/hang.bcskla",
    "actors/characters/samus/animations/hang2falldown.bcskla",
    "actors/characters/samus/animations/hang2falldownbottom.bcskla",
    "actors/characters/samus/animations/hang2falldowntop.bcskla",
    "actors/characters/samus/animations/hang2fallfront.bcskla",
    "actors/characters/samus/animations/hang2fallfrontbottom.bcskla",
    "actors/characters/samus/animations/hang2fallfronttop.bcskla",
    "actors/characters/samus/animations/hanganalog.bcskla",
    "actors/characters/samus/animations/hanganalogrecoil.bcskla",
    "actors/characters/samus/animations/hangclimb2mb.bcskla",
    "actors/characters/samus/animations/hangclimbfront.bcskla",
    "actors/characters/samus/animations/hangclimbfrontdown.bcskla",
    "actors/characters/samus/animations/hangclimbfrontdownbottom.bcskla",
    "actors/characters/samus/animations/hangclimbfrontup.bcskla",
    "actors/characters/samus/animations/hangclimbfrontupbottom.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilfront.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilfrontup.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilup.bcskla",
    "actors/characters/samus/animations/hangclimbrecoilupbottom.bcskla",
    "actors/characters/samus/animations/hangclimbup.bcskla",
    "actors/characters/samus/animations/hangclimbupbottom.bcskla",
    "actors/characters/samus/animations/hangdown.bcskla",
    "actors/characters/samus/animations/hangdownbottom.bcskla",
    "actors/characters/samus/animations/hangdowntop.bcskla",
    "actors/characters/samus/animations/hangfront.bcskla",
    "actors/characters/samus/animations/hangfrontbottom.bcskla",
    "actors/characters/samus/animations/hangfrontdown.bcskla",
    "actors/characters/samus/animations/hangfrontdownbottom.bcskla",
    "actors/characters/samus/animations/hangfrontdowntop.bcskla",
    "actors/characters/samus/animations/hangfronttop.bcskla",
    "actors/characters/samus/animations/hangfrontup.bcskla",
    "actors/characters/samus/animations/hangfrontupbottom.bcskla",
    "actors/characters/samus/animations/hangfrontuptop.bcskla",
    "actors/characters/samus/animations/hanginit.bcskla",
    "actors/characters/samus/animations/hanginitback.bcskla",
    "actors/characters/samus/animations/hangnoaimingdown.bcskla",
    "actors/characters/samus/animations/hangnoaimingdownbottom.bcskla",
    "actors/characters/samus/animations/hangnoaimingdowntop.bcskla",
    "actors/characters/samus/animations/hangnoaimingfront.bcskla",
    "actors/characters/samus/animations/hangrecoildown.bcskla",
    "actors/characters/samus/animations/hangrecoildownbottom.bcskla",
    "actors/characters/samus/animations/hangrecoildowntop.bcskla",
    "actors/characters/samus/animations/hangrecoilfront.bcskla",
    "actors/characters/samus/animations/hangrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/hangrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/hangrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/hangrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/hangrecoilfronttop.bcskla",
    "actors/characters/samus/animations/hangrecoilfrontup.bcskla",
    "actors/characters/samus/animations/hangrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/hangrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/hangrecoilup.bcskla",
    "actors/characters/samus/animations/hangrecoilupbottom.bcskla",
    "actors/characters/samus/animations/hangrecoiluptop.bcskla",
    "actors/characters/samus/animations/hangshot.bcskla",
    "actors/characters/samus/animations/hangshot2down.bcskla",
    "actors/characters/samus/animations/hangshot2downbottom.bcskla",
    "actors/characters/samus/animations/hangshot2downtop.bcskla",
    "actors/characters/samus/animations/hangshot2front.bcskla",
    "actors/characters/samus/animations/hangshot2frontbottom.bcskla",
    "actors/characters/samus/animations/hangshot2fronttop.bcskla",
    "actors/characters/samus/animations/hangshotbottom.bcskla",
    "actors/characters/samus/animations/hangshotend.bcskla",
    "actors/characters/samus/animations/hangshotendbottom.bcskla",
    "actors/characters/samus/animations/hangshotendfront.bcskla",
    "actors/characters/samus/animations/hangshotendfront2front.bcskla",
    "actors/characters/samus/animations/hangshotendtop.bcskla",
    "actors/characters/samus/animations/hangshotfire.bcskla",
    "actors/characters/samus/animations/hangshotfirebottom.bcskla",
    "actors/characters/samus/animations/hangshotfirefront.bcskla",
    "actors/characters/samus/animations/hangshotfireinit.bcskla",
    "actors/characters/samus/animations/hangshotfireinitbottom.bcskla",
    "actors/characters/samus/animations/hangshotfireinitfront.bcskla",
    "actors/characters/samus/animations/hangshotfireinittop.bcskla",
    "actors/characters/samus/animations/hangshotfiretop.bcskla",
    "actors/characters/samus/animations/hangshotfront.bcskla",
    "actors/characters/samus/animations/hangshottop.bcskla",
    "actors/characters/samus/animations/hangup.bcskla",
    "actors/characters/samus/animations/hangupbottom.bcskla",
    "actors/characters/samus/animations/hanguptop.bcskla",
    "actors/characters/samus/animations/highendrecoverfront.bcskla",
    "actors/characters/samus/animations/highendrecoverfrontdown.bcskla",
    "actors/characters/samus/animations/highendrecoverfrontup.bcskla",
    "actors/characters/samus/animations/highendrecoverup.bcskla",
    "actors/characters/samus/animations/impacthardfalldown.bcskla",
    "actors/characters/samus/animations/impacthardfallfront.bcskla",
    "actors/characters/samus/animations/impacthardfallfrontdown.bcskla",
    "actors/characters/samus/animations/impacthardfallfrontup.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoildown.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoildownbottom.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoildowntop.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfront.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfronttop.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfrontup.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilup.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoilupbottom.bcskla",
    "actors/characters/samus/animations/impacthardfallrecoiluptop.bcskla",
    "actors/characters/samus/animations/impacthardfallup.bcskla",
    "actors/characters/samus/animations/impactmedfalldown.bcskla",
    "actors/characters/samus/animations/impactmedfallfront.bcskla",
    "actors/characters/samus/animations/impactmedfallfrontdown.bcskla",
    "actors/characters/samus/animations/impactmedfallfrontup.bcskla",
    "actors/characters/samus/animations/impactmedfallrecoildown.bcskla",
    "actors/characters/samus/animations/impactmedfallrecoilfront.bcskla",
    "actors/characters/samus/animations/impactmedfallrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/impactmedfallrecoilfrontup.bcskla",
    "actors/characters/samus/animations/impactmedfallrecoilup.bcskla",
    "actors/characters/samus/animations/impactmedfallup.bcskla",
    "actors/characters/samus/animations/jump2falldown.bcskla",
    "actors/characters/samus/animations/jump2falldownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallfront.bcskla",
    "actors/characters/samus/animations/jump2fallfrontdown.bcskla",
    "actors/characters/samus/animations/jump2fallfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallfrontup.bcskla",
    "actors/characters/samus/animations/jump2fallfrontupbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitdown.bcskla",
    "actors/characters/samus/animations/jump2fallinitdownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitfront.bcskla",
    "actors/characters/samus/animations/jump2fallinitfrontdown.bcskla",
    "actors/characters/samus/animations/jump2fallinitfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitfrontup.bcskla",
    "actors/characters/samus/animations/jump2fallinitfrontupbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoildown.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoildownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilfront.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilfrontup.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilup.bcskla",
    "actors/characters/samus/animations/jump2fallinitrecoilupbottom.bcskla",
    "actors/characters/samus/animations/jump2fallinitup.bcskla",
    "actors/characters/samus/animations/jump2fallinitupbottom.bcskla",
    "actors/characters/samus/animations/jump2fallrecoildown.bcskla",
    "actors/characters/samus/animations/jump2fallrecoildownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilfront.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilfrontup.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilup.bcskla",
    "actors/characters/samus/animations/jump2fallrecoilupbottom.bcskla",
    "actors/characters/samus/animations/jump2fallup.bcskla",
    "actors/characters/samus/animations/jump2fallupbottom.bcskla",
    "actors/characters/samus/animations/jumpdown.bcskla",
    "actors/characters/samus/animations/jumpdownbottom.bcskla",
    "actors/characters/samus/animations/jumpfront.bcskla",
    "actors/characters/samus/animations/jumpfrontdown.bcskla",
    "actors/characters/samus/animations/jumpfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jumpfrontup.bcskla",
    "actors/characters/samus/animations/jumpfrontupbottom.bcskla",
    "actors/characters/samus/animations/jumpinitdown.bcskla",
    "actors/characters/samus/animations/jumpinitdownbottom.bcskla",
    "actors/characters/samus/animations/jumpinitfront.bcskla",
    "actors/characters/samus/animations/jumpinitfrontdown.bcskla",
    "actors/characters/samus/animations/jumpinitfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jumpinitfrontup.bcskla",
    "actors/characters/samus/animations/jumpinitfrontupbottom.bcskla",
    "actors/characters/samus/animations/jumpinitrecoildown.bcskla",
    "actors/characters/samus/animations/jumpinitrecoildownbottom.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilfront.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilfrontup.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilup.bcskla",
    "actors/characters/samus/animations/jumpinitrecoilupbottom.bcskla",
    "actors/characters/samus/animations/jumpinitup.bcskla",
    "actors/characters/samus/animations/jumpinitupbottom.bcskla",
    "actors/characters/samus/animations/jumprecoildown.bcskla",
    "actors/characters/samus/animations/jumprecoildownbottom.bcskla",
    "actors/characters/samus/animations/jumprecoilfront.bcskla",
    "actors/characters/samus/animations/jumprecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/jumprecoilfrontdown.bcskla",
    "actors/characters/samus/animations/jumprecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/jumprecoilfrontup.bcskla",
    "actors/characters/samus/animations/jumprecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/jumprecoilup.bcskla",
    "actors/characters/samus/animations/jumprecoilupbottom.bcskla",
    "actors/characters/samus/animations/jumpup.bcskla",
    "actors/characters/samus/animations/jumpupbottom.bcskla",
    "actors/characters/samus/animations/larvapanicbottom.bcskla",
    "actors/characters/samus/animations/larvapanictop.bcskla",
    "actors/characters/samus/animations/leftuse.bcskla",
    "actors/characters/samus/animations/leftuseabort.bcskla",
    "actors/characters/samus/animations/leftusedna.bcskla",
    "actors/characters/samus/animations/leftusednaend.bcskla",
    "actors/characters/samus/animations/leftusednainit.bcskla",
    "actors/characters/samus/animations/leftuseend.bcskla",
    "actors/characters/samus/animations/leftuseinit.bcskla",
    "actors/characters/samus/animations/loadingelevator.bcskla",
    "actors/characters/samus/animations/loadingteleport.bcskla",
    "actors/characters/samus/animations/mb2crouchfront.bcskla",
    "actors/characters/samus/animations/mb2crouchfrontdown.bcskla",
    "actors/characters/samus/animations/mb2crouchfrontup.bcskla",
    "actors/characters/samus/animations/mb2falldown.bcskla",
    "actors/characters/samus/animations/mb2fallfront.bcskla",
    "actors/characters/samus/animations/mb2fallfrontdown.bcskla",
    "actors/characters/samus/animations/mb2fallfrontup.bcskla",
    "actors/characters/samus/animations/mb2fallup.bcskla",
    "actors/characters/samus/animations/mb2relax.bcskla",
    "actors/characters/samus/animations/mb2relaxbottom.bcskla",
    "actors/characters/samus/animations/mb2relaxfront.bcskla",
    "actors/characters/samus/animations/mb2relaxfrontdown.bcskla",
    "actors/characters/samus/animations/mb2relaxfrontup.bcskla",
    "actors/characters/samus/animations/mb2relaxfrontuptop.bcskla",
    "actors/characters/samus/animations/mb2relaxtop.bcskla",
    "actors/characters/samus/animations/mb2relaxup.bcskla",
    "actors/characters/samus/animations/mbdeathbottom.bcskla",
    "actors/characters/samus/animations/mbdeathtop.bcskla",
    "actors/characters/samus/animations/melee.bcskla",
    "actors/characters/samus/animations/meleeback.bcskla",
    "actors/characters/samus/animations/meleebackbottom.bcskla",
    "actors/characters/samus/animations/meleebacktop.bcskla",
    "actors/characters/samus/animations/meleefail.bcskla",
    "actors/characters/samus/animations/meleefall.bcskla",
    "actors/characters/samus/animations/meleefallfail.bcskla",
    "actors/characters/samus/animations/meleefallfailbottom.bcskla",
    "actors/characters/samus/animations/meleefallfailtop.bcskla",
    "actors/characters/samus/animations/meleehang.bcskla",
    "actors/characters/samus/animations/meleehang2down.bcskla",
    "actors/characters/samus/animations/meleehang2front.bcskla",
    "actors/characters/samus/animations/meleehangfail.bcskla",
    "actors/characters/samus/animations/meleehangsuccess.bcskla",
    "actors/characters/samus/animations/meleehangsuccessbottom.bcskla",
    "actors/characters/samus/animations/meleehangsuccesstop.bcskla",
    "actors/characters/samus/animations/meleemb.bcskla",
    "actors/characters/samus/animations/meleesuccess.bcskla",
    "actors/characters/samus/animations/meleesuccessback.bcskla",
    "actors/characters/samus/animations/recievedna.bcskla",
    "actors/characters/samus/animations/recievednalastendleft.bcskla",
    "actors/characters/samus/animations/recievednalastendright.bcskla",
    "actors/characters/samus/animations/recievednalastinitleft.bcskla",
    "actors/characters/samus/animations/recievednalastinitright.bcskla",
    "actors/characters/samus/animations/recievednalastloopleft.bcskla",
    "actors/characters/samus/animations/recievednalastloopright.bcskla",
    "actors/characters/samus/animations/relax.bcskla",
    "actors/characters/samus/animations/relaxanalog.bcskla",
    "actors/characters/samus/animations/relaxanalogbottom.bcskla",
    "actors/characters/samus/animations/relaxanaloginvert.bcskla",
    "actors/characters/samus/animations/relaxanaloginvertbottom.bcskla",
    "actors/characters/samus/animations/relaxanaloginvertrecoil.bcskla",
    "actors/characters/samus/animations/relaxanaloginvertrecoilbottom.bcskla",
    "actors/characters/samus/animations/relaxanaloginvertrecoiltop.bcskla",
    "actors/characters/samus/animations/relaxanaloginverttop.bcskla",
    "actors/characters/samus/animations/relaxanalogrecoil.bcskla",
    "actors/characters/samus/animations/relaxanalogrecoilbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogrecoiltop.bcskla",
    "actors/characters/samus/animations/relaxanalogshort.bcskla",
    "actors/characters/samus/animations/relaxanalogshortbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogshortrecoil.bcskla",
    "actors/characters/samus/animations/relaxanalogshortrecoilbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogshortrecoiltop.bcskla",
    "actors/characters/samus/animations/relaxanalogshorttop.bcskla",
    "actors/characters/samus/animations/relaxanalogtop.bcskla",
    "actors/characters/samus/animations/relaxanalogwide.bcskla",
    "actors/characters/samus/animations/relaxanalogwidedna.bcskla",
    "actors/characters/samus/animations/relaxanalogwidednabottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwidednapull.bcskla",
    "actors/characters/samus/animations/relaxanalogwideinvert.bcskla",
    "actors/characters/samus/animations/relaxanalogwideinvertrecoil.bcskla",
    "actors/characters/samus/animations/relaxanalogwiderecoil.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfront.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontdown.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontdowndown.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontdowndownbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontdowndowntop.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontfrontdown.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontfrontup.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfronttop.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontup.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontupup.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontupupbottom.bcskla",
    "actors/characters/samus/animations/relaxanalogwideturnfrontupuptop.bcskla",
    "actors/characters/samus/animations/relaxbottom.bcskla",
    "actors/characters/samus/animations/relaxfront.bcskla",
    "actors/characters/samus/animations/relaxfront2dragwide.bcskla",
    "actors/characters/samus/animations/relaxfront2dragwidebottom.bcskla",
    "actors/characters/samus/animations/relaxfront2dragwidetop.bcskla",
    "actors/characters/samus/animations/relaxfrontdown.bcskla",
    "actors/characters/samus/animations/relaxfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxfrontpose.bcskla",
    "actors/characters/samus/animations/relaxfrontup.bcskla",
    "actors/characters/samus/animations/relaxfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxlaunchbotton.bcskla",
    "actors/characters/samus/animations/relaxlaunchbottonbottom.bcskla",
    "actors/characters/samus/animations/relaxlaunchbottontop.bcskla",
    "actors/characters/samus/animations/relaxlaunchtop.bcskla",
    "actors/characters/samus/animations/relaxlaunchtopbottom.bcskla",
    "actors/characters/samus/animations/relaxlaunchtoptop.bcskla",
    "actors/characters/samus/animations/relaxrecoilfront.bcskla",
    "actors/characters/samus/animations/relaxrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/relaxrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/relaxrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxrecoilfronttop.bcskla",
    "actors/characters/samus/animations/relaxrecoilfrontup.bcskla",
    "actors/characters/samus/animations/relaxrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxrecoilup.bcskla",
    "actors/characters/samus/animations/relaxrecoilupbottom.bcskla",
    "actors/characters/samus/animations/relaxrecoiluptop.bcskla",
    "actors/characters/samus/animations/relaxshotendfront.bcskla",
    "actors/characters/samus/animations/relaxshotendfrontdown.bcskla",
    "actors/characters/samus/animations/relaxshotendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxshotendfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxshotendfrontup.bcskla",
    "actors/characters/samus/animations/relaxshotendfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxshotendfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxshotendup.bcskla",
    "actors/characters/samus/animations/relaxshotfirefront.bcskla",
    "actors/characters/samus/animations/relaxshotfirefrontdown.bcskla",
    "actors/characters/samus/animations/relaxshotfirefrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxshotfirefrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxshotfirefrontup.bcskla",
    "actors/characters/samus/animations/relaxshotfirefrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxshotfirefrontuptop.bcskla",
    "actors/characters/samus/animations/relaxshotfireup.bcskla",
    "actors/characters/samus/animations/relaxshotfront.bcskla",
    "actors/characters/samus/animations/relaxshotfront2drag.bcskla",
    "actors/characters/samus/animations/relaxshotfrontdown.bcskla",
    "actors/characters/samus/animations/relaxshotfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxshotfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxshotfrontfrontup2drag.bcskla",
    "actors/characters/samus/animations/relaxshotfrontpose.bcskla",
    "actors/characters/samus/animations/relaxshotfrontup.bcskla",
    "actors/characters/samus/animations/relaxshotfrontup2drag.bcskla",
    "actors/characters/samus/animations/relaxshotfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxshotfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxshotfrontupup2drag.bcskla",
    "actors/characters/samus/animations/relaxshotinitfront.bcskla",
    "actors/characters/samus/animations/relaxshotinitfrontdown.bcskla",
    "actors/characters/samus/animations/relaxshotinitfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxshotinitfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxshotinitfrontup.bcskla",
    "actors/characters/samus/animations/relaxshotinitup.bcskla",
    "actors/characters/samus/animations/relaxshotup.bcskla",
    "actors/characters/samus/animations/relaxshotup2drag.bcskla",
    "actors/characters/samus/animations/relaxtop.bcskla",
    "actors/characters/samus/animations/relaxturnendfront.bcskla",
    "actors/characters/samus/animations/relaxturnendfrontbottom.bcskla",
    "actors/characters/samus/animations/relaxturnendfrontdown.bcskla",
    "actors/characters/samus/animations/relaxturnendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxturnendfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxturnendfronttop.bcskla",
    "actors/characters/samus/animations/relaxturnendfrontup.bcskla",
    "actors/characters/samus/animations/relaxturnendfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxturnendfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfront.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfronttop.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfrontup.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilup.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoilupbottom.bcskla",
    "actors/characters/samus/animations/relaxturnendrecoiluptop.bcskla",
    "actors/characters/samus/animations/relaxturnendup.bcskla",
    "actors/characters/samus/animations/relaxturnendupbottom.bcskla",
    "actors/characters/samus/animations/relaxturnenduptop.bcskla",
    "actors/characters/samus/animations/relaxturnfront.bcskla",
    "actors/characters/samus/animations/relaxturnfrontdown.bcskla",
    "actors/characters/samus/animations/relaxturnfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxturnfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxturnfrontup.bcskla",
    "actors/characters/samus/animations/relaxturnfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxturnfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfront.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfronttop.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfrontup.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilup.bcskla",
    "actors/characters/samus/animations/relaxturnrecoilupbottom.bcskla",
    "actors/characters/samus/animations/relaxturnrecoiluptop.bcskla",
    "actors/characters/samus/animations/relaxturnup.bcskla",
    "actors/characters/samus/animations/relaxturnupbottom.bcskla",
    "actors/characters/samus/animations/relaxup.bcskla",
    "actors/characters/samus/animations/relaxupbottom.bcskla",
    "actors/characters/samus/animations/rightuse.bcskla",
    "actors/characters/samus/animations/rightuseabort.bcskla",
    "actors/characters/samus/animations/rightusedna.bcskla",
    "actors/characters/samus/animations/rightusednaend.bcskla",
    "actors/characters/samus/animations/rightusednainit.bcskla",
    "actors/characters/samus/animations/rightuseend.bcskla",
    "actors/characters/samus/animations/rightuseinit.bcskla",
    "actors/characters/samus/animations/run.bcskla",
    "actors/characters/samus/animations/runend.bcskla",
    "actors/characters/samus/animations/runendbottom.bcskla",
    "actors/characters/samus/animations/runendfront.bcskla",
    "actors/characters/samus/animations/runendfrontdown.bcskla",
    "actors/characters/samus/animations/runendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runendfrontup.bcskla",
    "actors/characters/samus/animations/runendfrontupbottom.bcskla",
    "actors/characters/samus/animations/runendrecoilfront.bcskla",
    "actors/characters/samus/animations/runendrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/runendrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/runendrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runendrecoilfrontup.bcskla",
    "actors/characters/samus/animations/runendrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/runendrecoilup.bcskla",
    "actors/characters/samus/animations/runendrecoilupbottom.bcskla",
    "actors/characters/samus/animations/runendtop.bcskla",
    "actors/characters/samus/animations/runendup.bcskla",
    "actors/characters/samus/animations/runendupbottom.bcskla",
    "actors/characters/samus/animations/runfront.bcskla",
    "actors/characters/samus/animations/runfrontbottom.bcskla",
    "actors/characters/samus/animations/runfrontdown.bcskla",
    "actors/characters/samus/animations/runfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runfrontup.bcskla",
    "actors/characters/samus/animations/runfrontupbottom.bcskla",
    "actors/characters/samus/animations/runinitfront.bcskla",
    "actors/characters/samus/animations/runinitfrontdown.bcskla",
    "actors/characters/samus/animations/runinitfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runinitfrontup.bcskla",
    "actors/characters/samus/animations/runinitfrontupbottom.bcskla",
    "actors/characters/samus/animations/runinitrecoilfront.bcskla",
    "actors/characters/samus/animations/runinitrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/runinitrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/runinitrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runinitrecoilfrontup.bcskla",
    "actors/characters/samus/animations/runinitrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/runinitrecoilup.bcskla",
    "actors/characters/samus/animations/runinitrecoilupbottom.bcskla",
    "actors/characters/samus/animations/runinitup.bcskla",
    "actors/characters/samus/animations/runinitupbottom.bcskla",
    "actors/characters/samus/animations/runlaunchtop.bcskla",
    "actors/characters/samus/animations/runlaunchtopbottom.bcskla",
    "actors/characters/samus/animations/runlaunchtoptop.bcskla",
    "actors/characters/samus/animations/runrecoilfront.bcskla",
    "actors/characters/samus/animations/runrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/runrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/runrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runrecoilfrontup.bcskla",
    "actors/characters/samus/animations/runrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/runturn.bcskla",
    "actors/characters/samus/animations/runturnend.bcskla",
    "actors/characters/samus/animations/runturnend2relaxfront.bcskla",
    "actors/characters/samus/animations/runturnend2relaxfrontdown.bcskla",
    "actors/characters/samus/animations/runturnend2relaxfrontup.bcskla",
    "actors/characters/samus/animations/runturnend2relaxrecoilfront.bcskla",
    "actors/characters/samus/animations/runturnend2relaxrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/runturnend2relaxrecoilfrontup.bcskla",
    "actors/characters/samus/animations/runturnendbottom.bcskla",
    "actors/characters/samus/animations/runturnendfront.bcskla",
    "actors/characters/samus/animations/runturnendfrontdown.bcskla",
    "actors/characters/samus/animations/runturnendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runturnendfrontup.bcskla",
    "actors/characters/samus/animations/runturnendfrontupbottom.bcskla",
    "actors/characters/samus/animations/runturnendrecoilfront.bcskla",
    "actors/characters/samus/animations/runturnendrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/runturnendrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/runturnendrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runturnendrecoilfrontup.bcskla",
    "actors/characters/samus/animations/runturnendrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/runturnfront.bcskla",
    "actors/characters/samus/animations/runturnfrontbottom.bcskla",
    "actors/characters/samus/animations/runturnfrontdown.bcskla",
    "actors/characters/samus/animations/runturnfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runturnfrontdowntop.bcskla",
    "actors/characters/samus/animations/runturnfronttop.bcskla",
    "actors/characters/samus/animations/runturnfrontup.bcskla",
    "actors/characters/samus/animations/runturnfrontupbottom.bcskla",
    "actors/characters/samus/animations/runturnfrontuptop.bcskla",
    "actors/characters/samus/animations/runturnrecoilfront.bcskla",
    "actors/characters/samus/animations/runturnrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/runturnrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/runturnrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/runturnrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/runturnrecoilfronttop.bcskla",
    "actors/characters/samus/animations/runturnrecoilfrontup.bcskla",
    "actors/characters/samus/animations/runturnrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/runturnrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/shortcrouchfront.bcskla",
    "actors/characters/samus/animations/shortcrouchfrontbottom.bcskla",
    "actors/characters/samus/animations/shortcrouchfrontdown.bcskla",
    "actors/characters/samus/animations/shortcrouchfrontdownbottom.bcskla",
    "actors/characters/samus/animations/shortcrouchfrontdowntop.bcskla",
    "actors/characters/samus/animations/shortcrouchfronttop.bcskla",
    "actors/characters/samus/animations/shortcrouchrecoilfront.bcskla",
    "actors/characters/samus/animations/shortcrouchrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/shortcrouchrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/shortcrouchrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/shortcrouchrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/shortcrouchrecoilfronttop.bcskla",
    "actors/characters/samus/animations/shorthangfront.bcskla",
    "actors/characters/samus/animations/shorthangfrontbottom.bcskla",
    "actors/characters/samus/animations/shorthangfrontdown.bcskla",
    "actors/characters/samus/animations/shorthangfrontdownbottom.bcskla",
    "actors/characters/samus/animations/shorthangfrontdowntop.bcskla",
    "actors/characters/samus/animations/shorthangfronttop.bcskla",
    "actors/characters/samus/animations/shorthangfrontup.bcskla",
    "actors/characters/samus/animations/shorthangfrontupbottom.bcskla",
    "actors/characters/samus/animations/shorthangfrontuptop.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfront.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfronttop.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfrontup.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/shorthangrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/shortrelaxfront.bcskla",
    "actors/characters/samus/animations/shortrelaxfrontbottom.bcskla",
    "actors/characters/samus/animations/shortrelaxfronttop.bcskla",
    "actors/characters/samus/animations/shortrelaxrecoilfront.bcskla",
    "actors/characters/samus/animations/shortrelaxrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/shortrelaxrecoilfronttop.bcskla",
    "actors/characters/samus/animations/shortrelaxturnendfront.bcskla",
    "actors/characters/samus/animations/shortrelaxturnendfrontbottom.bcskla",
    "actors/characters/samus/animations/shortrelaxturnendfronttop.bcskla",
    "actors/characters/samus/animations/shortrelaxturnendrecoilfront.bcskla",
    "actors/characters/samus/animations/shortrelaxturnendrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/shortrelaxturnendrecoilfronttop.bcskla",
    "actors/characters/samus/animations/shortrelaxturnfront.bcskla",
    "actors/characters/samus/animations/shortrelaxturnfrontbottom.bcskla",
    "actors/characters/samus/animations/shortrelaxturnfronttop.bcskla",
    "actors/characters/samus/animations/shortrelaxturnrecoilfront.bcskla",
    "actors/characters/samus/animations/shortrelaxturnrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/shortrelaxturnrecoilfronttop.bcskla",
    "actors/characters/samus/animations/spin2falldown.bcskla",
    "actors/characters/samus/animations/spin2fallfront.bcskla",
    "actors/characters/samus/animations/spin2fallfrontdown.bcskla",
    "actors/characters/samus/animations/spin2fallfrontup.bcskla",
    "actors/characters/samus/animations/spin2fallrecoildown.bcskla",
    "actors/characters/samus/animations/spin2fallrecoilfront.bcskla",
    "actors/characters/samus/animations/spin2fallrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/spin2fallrecoilfrontup.bcskla",
    "actors/characters/samus/animations/spin2fallrecoilup.bcskla",
    "actors/characters/samus/animations/spin2fallup.bcskla",
    "actors/characters/samus/animations/spinfall.bcskla",
    "actors/characters/samus/animations/spinfallend2run.bcskla",
    "actors/characters/samus/animations/spinfallend2runfront.bcskla",
    "actors/characters/samus/animations/spinfallend2runfrontbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2runfrontdown.bcskla",
    "actors/characters/samus/animations/spinfallend2runfrontdownbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2runfrontup.bcskla",
    "actors/characters/samus/animations/spinfallend2runfrontupbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2runrecoilfront.bcskla",
    "actors/characters/samus/animations/spinfallend2runrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2runrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/spinfallend2runrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2runrecoilfrontup.bcskla",
    "actors/characters/samus/animations/spinfallend2runrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2walk.bcskla",
    "actors/characters/samus/animations/spinfallend2walkfront.bcskla",
    "actors/characters/samus/animations/spinfallend2walkfrontbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2walkfrontdown.bcskla",
    "actors/characters/samus/animations/spinfallend2walkfrontdownbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2walkfrontup.bcskla",
    "actors/characters/samus/animations/spinfallend2walkfrontupbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2walkrecoilfront.bcskla",
    "actors/characters/samus/animations/spinfallend2walkrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2walkrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/spinfallend2walkrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/spinfallend2walkrecoilfrontup.bcskla",
    "actors/characters/samus/animations/spinfallend2walkrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/spinfallendfront.bcskla",
    "actors/characters/samus/animations/spinfallendfrontdown.bcskla",
    "actors/characters/samus/animations/spinfallendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/spinfallendfrontup.bcskla",
    "actors/characters/samus/animations/spinfallendfrontupbottom.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilfront.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilfrontup.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilup.bcskla",
    "actors/characters/samus/animations/spinfallendrecoilupbottom.bcskla",
    "actors/characters/samus/animations/spinfallendup.bcskla",
    "actors/characters/samus/animations/spinfallendupbottom.bcskla",
    "actors/characters/samus/animations/spinfallhighendfront.bcskla",
    "actors/characters/samus/animations/spinfallhighendfrontdown.bcskla",
    "actors/characters/samus/animations/spinfallhighendfrontup.bcskla",
    "actors/characters/samus/animations/spinfallhighendup.bcskla",
    "actors/characters/samus/animations/spinjumpinit.bcskla",
    "actors/characters/samus/animations/turnanalogfront.bcskla",
    "actors/characters/samus/animations/turnanalogfrontdown.bcskla",
    "actors/characters/samus/animations/turnanalogfrontdownbottom.bcskla",
    "actors/characters/samus/animations/turnanalogfrontup.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfront.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfrontdowntop.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfronttop.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfrontup.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/turnanalogrecoilfrontuptop.bcskla",
    "actors/characters/samus/animations/usecharge.bcskla",
    "actors/characters/samus/animations/usechargeend.bcskla",
    "actors/characters/samus/animations/usechargeinit.bcskla",
    "actors/characters/samus/animations/usechargeleftinit.bcskla",
    "actors/characters/samus/animations/usechargerightinit.bcskla",
    "actors/characters/samus/animations/usechargetocheckdna.bcskla",
    "actors/characters/samus/animations/usednainit.bcskla",
    "actors/characters/samus/animations/useelevator.bcskla",
    "actors/characters/samus/animations/useplatform.bcskla",
    "actors/characters/samus/animations/useplatformend.bcskla",
    "actors/characters/samus/animations/useplatforminit.bcskla",
    "actors/characters/samus/animations/usestation.bcskla",
    "actors/characters/samus/animations/useteleporterend.bcskla",
    "actors/characters/samus/animations/useteleporterinit.bcskla",
    "actors/characters/samus/animations/waiting.bcskla",
    "actors/characters/samus/animations/waitingbattle.bcskla",
    "actors/characters/samus/animations/walk.bcskla",
    "actors/characters/samus/animations/walkcharge.bcskla",
    "actors/characters/samus/animations/walkchargebottom.bcskla",
    "actors/characters/samus/animations/walkchargetop.bcskla",
    "actors/characters/samus/animations/walkfront.bcskla",
    "actors/characters/samus/animations/walkfrontbottom.bcskla",
    "actors/characters/samus/animations/walkfrontdown.bcskla",
    "actors/characters/samus/animations/walkfrontdownbottom.bcskla",
    "actors/characters/samus/animations/walkfrontup.bcskla",
    "actors/characters/samus/animations/walkfrontupbottom.bcskla",
    "actors/characters/samus/animations/walkrecoilfront.bcskla",
    "actors/characters/samus/animations/walkrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/walkrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/walkrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/walkrecoilfrontup.bcskla",
    "actors/characters/samus/animations/walkrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/walkturnend.bcskla",
    "actors/characters/samus/animations/walkturnendbottom.bcskla",
    "actors/characters/samus/animations/walkturnendfront.bcskla",
    "actors/characters/samus/animations/walkturnendfrontdown.bcskla",
    "actors/characters/samus/animations/walkturnendfrontdownbottom.bcskla",
    "actors/characters/samus/animations/walkturnendfrontup.bcskla",
    "actors/characters/samus/animations/walkturnendfrontupbottom.bcskla",
    "actors/characters/samus/animations/walkturnendrecoilfront.bcskla",
    "actors/characters/samus/animations/walkturnendrecoilfrontbottom.bcskla",
    "actors/characters/samus/animations/walkturnendrecoilfrontdown.bcskla",
    "actors/characters/samus/animations/walkturnendrecoilfrontdownbottom.bcskla",
    "actors/characters/samus/animations/walkturnendrecoilfrontup.bcskla",
    "actors/characters/samus/animations/walkturnendrecoilfrontupbottom.bcskla",
    "actors/characters/samus/animations/walkturnendtop.bcskla",
    "actors/characters/tsumuri/animations/crazy.bcskla",
    "actors/items/itemsphere/animations/drop.bcskla",
    "actors/props/doorcreatureleft/animations/death.bcskla",
    "actors/props/doorcreatureleft/animations/impact.bcskla",
    "actors/props/doorcreatureleft/animations/relax.bcskla",
    "actors/props/menu_planet/animations/relax.bcskla",
    "actors/props/menu_samus/animations/menuinteract2.bcskla",
    "actors/props/menu_samus/animations/menuinteract3.bcskla",
    "actors/props/menu_samus/animations/menuinteract4.bcskla",
    "actors/props/menu_samus/animations/menurelax.bcskla",
    "actors/props/planet/animations/relax.bcskla",
    "maps/objects/animadorn1002/animadorn1002.bcskla",
    "maps/objects/animplant0602b/animplant0602b.bcskla",
]


@pytest.mark.parametrize("bcskla_path", dread_data.all_files_ending_with(".bcskla"))
def test_bcskla_dread(dread_tree_100, bcskla_path):
    parse_build_compare_editor(Bcskla, dread_tree_100, bcskla_path)


@pytest.mark.parametrize("bcskla_path", samus_returns_data.all_files_ending_with(".bcskla", sr_missing))
def test_bcskla_sr(samus_returns_tree, bcskla_path):
    parse_build_compare_editor(Bcskla, samus_returns_tree, bcskla_path)
