from __future__ import annotations

import pytest
from tests.test_lib import parse_build_compare_editor_parsed

from mercury_engine_data_structures import dread_data, samus_returns_data
from mercury_engine_data_structures.formats.bctex import Bctex

dread_exclusions = [
    # exceptionally slow file
    "textures/system/fx/tests/watertank/textures/watertank_col.bctex",
]

# these are existing textures that bytematch existing ones. likely put in the bossrush pkgs for performance.
dread_210_ignore = [
    "actors/characters/centralunitcave/fx/textures/centralunit_flash.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave01_at.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave01_bc.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave01_nm.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave02_at.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave02_bc.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave02_nm.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave03_at.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave03_bc.bctex",
    "actors/characters/centralunitcave/models/textures/centralunitcave03_nm.bctex",
    "actors/characters/chozocommander/models/textures/commanderbody_at.bctex",
    "actors/characters/chozocommander/models/textures/commanderbody_bc.bctex",
    "actors/characters/chozocommander/models/textures/commanderbody_nm.bctex",
    "actors/characters/chozocommander/models/textures/commandercanon_at.bctex",
    "actors/characters/chozocommander/models/textures/commandercanon_bc.bctex",
    "actors/characters/chozocommander/models/textures/commandercanon_nm.bctex",
    "actors/characters/chozocommander/models/textures/commandercap_at.bctex",
    "actors/characters/chozocommander/models/textures/commandercap_bc.bctex",
    "actors/characters/chozocommander/models/textures/commandercap_nm.bctex",
    "actors/characters/chozocommander/models/textures/commanderhead_at.bctex",
    "actors/characters/chozocommander/models/textures/commanderhead_bc.bctex",
    "actors/characters/chozocommander/models/textures/commanderhead_cine_at.bctex",
    "actors/characters/chozocommander/models/textures/commanderhead_cine_bc.bctex",
    "actors/characters/chozocommander/models/textures/commanderhead_cine_nm.bctex",
    "actors/characters/chozocommander/models/textures/commanderhead_nm.bctex",
    "actors/characters/chozocommander/models/textures/commanderheadclean_at.bctex",
    "actors/characters/chozocommander/models/textures/commanderheadclean_bc.bctex",
    "actors/characters/chozocommander/models/textures/commanderheadclean_nm.bctex",
    "actors/characters/chozocommander/models/textures/commanderwings_at.bctex",
    "actors/characters/chozocommander/models/textures/commanderwings_bc.bctex",
    "actors/characters/chozocommander/models/textures/commanderwings_nm.bctex",
    "actors/characters/chozowarrior/fx/textures/noise.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_body_02_at.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_body_02_bc.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_body_02_nm.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_body_at.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_body_bc.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_body_nm.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_weapons_at.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_weapons_bc.bctex",
    "actors/characters/chozowarriorelite/models/textures/chozowarriorelite_weapons_nm.bctex",
    "actors/characters/cooldownxboss/models/textures/cooldown_arms_at.bctex",
    "actors/characters/cooldownxboss/models/textures/cooldown_arms_bc.bctex",
    "actors/characters/cooldownxboss/models/textures/cooldown_arms_nm.bctex",
    "actors/characters/cooldownxboss/models/textures/cooldown_body_bc.bctex",
    "actors/characters/cooldownxboss/models/textures/cooldown_head_at.bctex",
    "actors/characters/cooldownxboss/models/textures/cooldown_head_bc.bctex",
    "actors/characters/cooldownxboss/models/textures/cooldown_head_nm.bctex",
    "actors/characters/cooldownxboss/models/textures/detail_bc.bctex",
    "actors/characters/cooldownxboss/models/textures/waves_cdboss_nm.bctex",
    "actors/characters/core_x/models/textures/core_x_alpha_bc.bctex",
    "actors/characters/core_x/models/textures/core_x_alpha_nm.bctex",
    "actors/characters/core_x/models/textures/core_x_at.bctex",
    "actors/characters/core_x/models/textures/core_x_bc.bctex",
    "actors/characters/core_x/models/textures/core_x_nm.bctex",
    "actors/characters/emmycave/models/textures/emmyburn.bctex",
    "actors/characters/emmycave/models/textures/emmycaveblack02_at.bctex",
    "actors/characters/emmycave/models/textures/emmycaveblack02_bc.bctex",
    "actors/characters/emmycave/models/textures/emmycaveblack02_nm.bctex",
    "actors/characters/emmycave/models/textures/emmycaveblack_at.bctex",
    "actors/characters/emmycave/models/textures/emmycaveblack_bc.bctex",
    "actors/characters/emmycave/models/textures/emmycaveblack_nm.bctex",
    "actors/characters/emmycave/models/textures/emmycavewhite_at.bctex",
    "actors/characters/emmycave/models/textures/emmycavewhite_bc.bctex",
    "actors/characters/emmycave/models/textures/emmycavewhite_nm.bctex",
    "actors/characters/emmycave/models/textures/emmydestoyed_at.bctex",
    "actors/characters/emmycave/models/textures/emmydestoyed_bc.bctex",
    "actors/characters/emmycave/models/textures/emmydestoyed_nm.bctex",
    "actors/characters/emmyproto/models/textures/emmy_crackedglass_at.bctex",
    "actors/characters/emmyproto/models/textures/emmy_crackedglass_bc.bctex",
    "actors/characters/emmyproto/models/textures/emmy_crackedglass_nm.bctex",
    "actors/characters/gooplot/models/textures/gooplot_detail_nm.bctex",
    "actors/characters/hydrogiga/models/textures/body_bc.bctex",
    "actors/characters/hydrogiga/models/textures/body_nm.bctex",
    "actors/characters/hydrogiga/models/textures/hydro_tile_at.bctex",
    "actors/characters/hydrogiga/models/textures/hydro_tile_bc.bctex",
    "actors/characters/hydrogiga/models/textures/hydro_tile_nm.bctex",
    "actors/characters/hydrogiga/models/textures/pistil_bc.bctex",
    "actors/characters/hydrogiga/models/textures/pistil_nm.bctex",
    "actors/characters/hydrogiga/models/textures/roots_bc.bctex",
    "actors/characters/hydrogiga/models/textures/roots_nm.bctex",
    "actors/characters/hydrogiga/models/textures/tentaculos_at.bctex",
    "actors/characters/hydrogiga/models/textures/tentaculos_bc.bctex",
    "actors/characters/hydrogiga/models/textures/tentaculos_dead_at.bctex",
    "actors/characters/hydrogiga/models/textures/tentaculos_dead_bc.bctex",
    "actors/characters/hydrogiga/models/textures/tentaculos_dead_nm.bctex",
    "actors/characters/hydrogiga/models/textures/tentaculos_nm.bctex",
    "actors/characters/kraid/models/textures/kraid_barriga_at.bctex",
    "actors/characters/kraid/models/textures/kraid_barriga_bc.bctex",
    "actors/characters/kraid/models/textures/kraid_barriga_nm.bctex",
    "actors/characters/kraid/models/textures/kraid_bellydamage.bctex",
    "actors/characters/kraid/models/textures/kraid_cabeza_at.bctex",
    "actors/characters/kraid/models/textures/kraid_cabeza_bc.bctex",
    "actors/characters/kraid/models/textures/kraid_cabeza_nm.bctex",
    "actors/characters/kraid/models/textures/kraid_cuerpo_at.bctex",
    "actors/characters/kraid/models/textures/kraid_cuerpo_bc.bctex",
    "actors/characters/kraid/models/textures/kraid_cuerpo_nm.bctex",
    "actors/characters/kraid/models/textures/kraid_hardsurface_bc.bctex",
    "actors/characters/kraid/models/textures/kraid_hardsurface_nm.bctex",
    "actors/characters/morphball/models/textures/morphball_power_at.bctex",
    "actors/characters/morphball/models/textures/morphball_power_bc.bctex",
    "actors/characters/morphball/models/textures/morphball_power_nm.bctex",
    "actors/characters/morphball/models/textures/morphballgravity_at.bctex",
    "actors/characters/morphball/models/textures/morphballgravity_bc.bctex",
    "actors/characters/morphball/models/textures/morphballgravity_nm.bctex",
    "actors/characters/morphball/models/textures/morphballhyper_at.bctex",
    "actors/characters/morphball/models/textures/morphballhyper_bc.bctex",
    "actors/characters/morphball/models/textures/morphballhyper_nm.bctex",
    "actors/characters/morphball/models/textures/morphballvaria_at.bctex",
    "actors/characters/morphball/models/textures/morphballvaria_bc.bctex",
    "actors/characters/morphball/models/textures/morphballvaria_nm.bctex",
    "actors/characters/omnithon/models/textures/omnithon_at.bctex",
    "actors/characters/omnithon/models/textures/omnithon_bc.bctex",
    "actors/characters/omnithon/models/textures/omnithon_nm.bctex",
    "actors/characters/samus/fx/textures/melee.bctex",
    "actors/characters/samus/fx/textures/samus_splashenter_nor.bctex",
    "actors/characters/samus/fx/textures/samus_splashenter_pos.bctex",
    "actors/characters/samus/models/textures/gravity_body_at.bctex",
    "actors/characters/samus/models/textures/gravity_body_bc.bctex",
    "actors/characters/samus/models/textures/gravity_body_nm.bctex",
    "actors/characters/samus/models/textures/gravity_hand_at.bctex",
    "actors/characters/samus/models/textures/gravity_hand_bc.bctex",
    "actors/characters/samus/models/textures/gravity_hand_nm.bctex",
    "actors/characters/samus/models/textures/gravity_head_at.bctex",
    "actors/characters/samus/models/textures/gravity_head_bc.bctex",
    "actors/characters/samus/models/textures/gravity_head_nm.bctex",
    "actors/characters/samus/models/textures/hyper_body_at.bctex",
    "actors/characters/samus/models/textures/hyper_body_bc.bctex",
    "actors/characters/samus/models/textures/hyper_body_nm.bctex",
    "actors/characters/samus/models/textures/hyper_cannon_at.bctex",
    "actors/characters/samus/models/textures/hyper_cannon_bc.bctex",
    "actors/characters/samus/models/textures/hyper_cannon_nm.bctex",
    "actors/characters/samus/models/textures/hyper_head_at.bctex",
    "actors/characters/samus/models/textures/hyper_head_bc.bctex",
    "actors/characters/samus/models/textures/hyper_head_nm.bctex",
    "actors/characters/samus/models/textures/metroidnization_n0.bctex",
    "actors/characters/samus/models/textures/metroidnization_n1.bctex",
    "actors/characters/samus/models/textures/metroidnization_n2.bctex",
    "actors/characters/samus/models/textures/powerbody_at.bctex",
    "actors/characters/samus/models/textures/powerbody_bc.bctex",
    "actors/characters/samus/models/textures/powerbody_nm.bctex",
    "actors/characters/samus/models/textures/powerhead_at.bctex",
    "actors/characters/samus/models/textures/powerhead_bc.bctex",
    "actors/characters/samus/models/textures/powerhead_nm.bctex",
    "actors/characters/samus/models/textures/samus_sburst_at.bctex",
    "actors/characters/samus/models/textures/samus_sburst_bc.bctex",
    "actors/characters/samus/models/textures/samus_sburst_nm.bctex",
    "actors/characters/samus/models/textures/samuscannon_at.bctex",
    "actors/characters/samus/models/textures/samuscannon_bc.bctex",
    "actors/characters/samus/models/textures/samuscannon_nm.bctex",
    "actors/characters/samus/models/textures/varia_body_at.bctex",
    "actors/characters/samus/models/textures/varia_body_bc.bctex",
    "actors/characters/samus/models/textures/varia_body_nm.bctex",
    "actors/characters/samus/models/textures/varia_head_at.bctex",
    "actors/characters/samus/models/textures/varia_head_bc.bctex",
    "actors/characters/samus/models/textures/varia_head_nm.bctex",
    "actors/characters/scorpius/fx/textures/noise_regenerate.bctex",
    "actors/characters/scorpius/fx/textures/scorpius_trail.bctex",
    "actors/characters/scorpius/models/textures/scorpius_at.bctex",
    "actors/characters/scorpius/models/textures/scorpius_bc.bctex",
    "actors/characters/scorpius/models/textures/scorpius_nm.bctex",
    "actors/characters/scorpius/models/textures/scorpiushead_at.bctex",
    "actors/characters/scorpius/models/textures/scorpiushead_bc.bctex",
    "actors/characters/scorpius/models/textures/scorpiushead_nm.bctex",
    "actors/events/mapev_fish_b/models/textures/default_at.bctex",
    "actors/events/mapev_fish_b/models/textures/default_bc.bctex",
    "actors/events/mapev_fish_b/models/textures/default_nm.bctex",
    "actors/events/mapev_lum_ell/models/textures/mapev_lum_ell_at.bctex",
    "actors/events/mapev_lum_ell/models/textures/mapev_lum_ell_bc.bctex",
    "actors/events/mapev_lum_ell/models/textures/mapev_lum_ell_nm.bctex",
    "actors/events/mapev_plant003/models/textures/mapev_plant003_at.bctex",
    "actors/events/mapev_plant003/models/textures/mapev_plant003_bc.bctex",
    "actors/events/mapev_plant003/models/textures/mapev_plant003_nm.bctex",
    "actors/events/mapev_siluro/models/textures/siluro_at.bctex",
    "actors/events/mapev_siluro/models/textures/siluro_bc.bctex",
    "actors/events/mapev_siluro/models/textures/siluro_nm.bctex",
    "actors/items/drop_life/fx/textures/drop_life.bctex",
    "actors/items/item_cube/model/textures/cube_at.bctex",
    "actors/items/item_cube/model/textures/cube_bc.bctex",
    "actors/items/item_cube/model/textures/cube_nm.bctex",
    "actors/items/item_missiletank/models/textures/bordershexagonal.bctex",
    "actors/items/item_missiletank/models/textures/lines_red.bctex",
    "actors/items/item_missiletankplus/models/textures/bordershexagonal.bctex",
    "actors/items/item_missiletankplus/models/textures/lines.bctex",
    "actors/items/item_powerbombtank/models/textures/bordershexagonal.bctex",
    "actors/items/item_powerbombtank/models/textures/lines.bctex",
    "actors/props/accesspoint/fx/textures/letters_hologram_noise.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/a_at.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/a_bc.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/a_nm.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/b_at.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/b_bc.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/b_nm.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsula_capsula_at.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsula_capsula_bc.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsula_capsula_nm.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsula_interior_at.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsula_interior_bc.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsula_interior_nm.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsule_roof_hatch_at.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsule_roof_hatch_bc.bctex",
    "actors/props/capsulelaunchershipyard/models/textures/capsule_roof_hatch_nm.bctex",
    "actors/props/commander_elevator/models/textures/commander_elevator_at.bctex",
    "actors/props/commander_elevator/models/textures/commander_elevator_bc.bctex",
    "actors/props/commander_elevator/models/textures/commander_elevator_nm.bctex",
    "actors/props/doorcentralunit/models/textures/doorcentralunit_at.bctex",
    "actors/props/doorcentralunit/models/textures/doorcentralunit_bc.bctex",
    "actors/props/doorcentralunit/models/textures/doorcentralunit_nm.bctex",
    "actors/props/doorcentralunit/models/textures/doorcentralunithit_at.bctex",
    "actors/props/doorcentralunit/models/textures/doorcentralunithit_bc.bctex",
    "actors/props/doorcentralunit/models/textures/doorcentralunithit_nm.bctex",
    "actors/props/doorcentralunit/models/textures/doorcentralunithitburn.bctex",
    "actors/props/doorchargecharge/models/textures/doorcharge_at.bctex",
    "actors/props/doorchargecharge/models/textures/doorcharge_bc.bctex",
    "actors/props/doorchargecharge/models/textures/doorcharge_nm.bctex",
    "actors/props/doorchargecharge/models/textures/doorfrozen_at.bctex",
    "actors/props/doorchargecharge/models/textures/doorfrozen_bc.bctex",
    "actors/props/doorchargecharge/models/textures/doorfrozen_nm.bctex",
    "actors/props/doorchargecharge/models/textures/sabotoru_nest_eggs_at.bctex",
    "actors/props/doorchargecharge/models/textures/sabotoru_nest_eggs_bc.bctex",
    "actors/props/doorchargecharge/models/textures/sabotoru_nest_eggs_nm.bctex",
    "actors/props/doorchargecharge/models/textures/sabotoru_nest_slime_at.bctex",
    "actors/props/doorchargecharge/models/textures/sabotoru_nest_slime_bc.bctex",
    "actors/props/doorchargecharge/models/textures/sabotoru_nest_slime_nm.bctex",
    "actors/props/doorclosedcharge/models/textures/doorchargeclosed_at.bctex",
    "actors/props/doorclosedcharge/models/textures/doorchargeclosed_bc.bctex",
    "actors/props/doorclosedcharge/models/textures/doorchargeclosed_nm.bctex",
    "actors/props/doorpresencepresence/models/textures/doorpresence_at.bctex",
    "actors/props/doorpresencepresence/models/textures/doorpresence_bc.bctex",
    "actors/props/doorpresencepresence/models/textures/doorpresence_nm.bctex",
    "actors/props/doorpresencepresence/models/textures/doorpresencehall_at.bctex",
    "actors/props/doorpresencepresence/models/textures/doorpresencehall_bc.bctex",
    "actors/props/doorpresencepresence/models/textures/doorpresencehall_nm.bctex",
    "actors/props/doorshieldmissile/fx/textures/doorshieldmissile_fx.bctex",
    "actors/props/doorshieldmissile/models/textures/doorshieldmissile_at.bctex",
    "actors/props/doorshieldmissile/models/textures/doorshieldmissile_bc.bctex",
    "actors/props/doorshieldmissile/models/textures/doorshieldmissile_nm.bctex",
    "actors/props/doorshutter/models/textures/doorshutter_at.bctex",
    "actors/props/doorshutter/models/textures/doorshutter_bc.bctex",
    "actors/props/doorshutter/models/textures/doorshutter_nm.bctex",
    "actors/props/doorwavebeam/models/textures/circuitevolution.bctex",
    "actors/props/doorwavebeam/models/textures/doorwavebeam_at.bctex",
    "actors/props/doorwavebeam/models/textures/doorwavebeam_bc.bctex",
    "actors/props/doorwavebeam/models/textures/doorwavebeam_nm.bctex",
    "actors/props/elevator/fx/textures/elevator_steam03.bctex",
    "actors/props/ev_aquadrain_right/models/textures/ev_aquadrain_right_at.bctex",
    "actors/props/ev_aquadrain_right/models/textures/ev_aquadrain_right_bc.bctex",
    "actors/props/ev_aquadrain_right/models/textures/ev_aquadrain_right_nm.bctex",
    "actors/props/ev_entercu_cv_001/models/textures/ev_entercu_cv_001_at.bctex",
    "actors/props/ev_entercu_cv_001/models/textures/ev_entercu_cv_001_bc.bctex",
    "actors/props/ev_entercu_cv_001/models/textures/ev_entercu_cv_001_nm.bctex",
    "actors/props/ev_tbdrainboss/models/textures/shootactivator_at.bctex",
    "actors/props/ev_tbdrainboss/models/textures/shootactivator_bc.bctex",
    "actors/props/ev_tbdrainboss/models/textures/shootactivator_nm.bctex",
    "actors/props/fusiblebox/models/textures/fusiblebox_at.bctex",
    "actors/props/fusiblebox/models/textures/fusiblebox_bc.bctex",
    "actors/props/fusiblebox/models/textures/fusiblebox_nm.bctex",
    "actors/props/grapplepulloff1x2/fx/textures/noise_dissolve.bctex",
    "actors/props/grapplepulloff1x2/models/textures/grapplepulloff1x2_at.bctex",
    "actors/props/grapplepulloff1x2/models/textures/grapplepulloff1x2_bc.bctex",
    "actors/props/grapplepulloff1x2/models/textures/grapplepulloff1x2_nm.bctex",
    "actors/props/hydrogigacorpse/models/textures/body_dead_at.bctex",
    "actors/props/hydrogigacorpse/models/textures/body_dead_bc.bctex",
    "actors/props/hydrogigacorpse/models/textures/body_dead_nm.bctex",
    "actors/props/hydrogigacorpse/models/textures/head_dead_at.bctex",
    "actors/props/hydrogigacorpse/models/textures/head_dead_bc.bctex",
    "actors/props/hydrogigacorpse/models/textures/head_dead_nm.bctex",
    "actors/props/hydrogigacorpse/models/textures/roots_dead_at.bctex",
    "actors/props/hydrogigacorpse/models/textures/roots_dead_bc.bctex",
    "actors/props/hydrogigacorpse/models/textures/roots_dead_nm.bctex",
    "actors/props/mblauncher_exit_gen_001/models/textures/mblauncher_launcher_at.bctex",
    "actors/props/mblauncher_exit_gen_001/models/textures/mblauncher_launcher_bc.bctex",
    "actors/props/mblauncher_exit_gen_001/models/textures/mblauncher_launcher_nm.bctex",
    "actors/props/mblauncher_launcher_gen_001/models/textures/mblauncher_launcher_at.bctex",
    "actors/props/mblauncher_launcher_gen_001/models/textures/mblauncher_launcher_bc.bctex",
    "actors/props/mblauncher_launcher_gen_001/models/textures/mblauncher_launcher_nm.bctex",
    "actors/props/pistonmag01/models/textures/pistonmagma_at.bctex",
    "actors/props/pistonmag01/models/textures/pistonmagma_bc.bctex",
    "actors/props/pistonmag01/models/textures/pistonmagma_nm.bctex",
    "actors/props/pistonmag01/models/textures/shootactivator_at.bctex",
    "actors/props/pistonmag01/models/textures/shootactivator_bc.bctex",
    "actors/props/pistonmag01/models/textures/shootactivator_nm.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_end_nor.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_end_pos.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_end_pos2.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_init_nor.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_init_pos.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_init_pos2.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_loop_nor.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_loop_pos.bctex",
    "actors/props/platformcavewaterb/fx/textures/water_loop_pos2.bctex",
    "actors/props/rinkaunit/fx/textures/rinca_shaft.bctex",
    "actors/props/rinkaunit/fx/textures/rinka_center.bctex",
    "actors/props/rinkaunit/models/textures/rinkaunit_at.bctex",
    "actors/props/rinkaunit/models/textures/rinkaunit_bc.bctex",
    "actors/props/rinkaunit/models/textures/rinkaunit_nm.bctex",
    "actors/props/shootactivator/models/textures/shootactivator_at.bctex",
    "actors/props/shootactivator/models/textures/shootactivator_bc.bctex",
    "actors/props/shootactivator/models/textures/shootactivator_nm.bctex",
    "actors/props/shootactivatorhidrogiga/models/textures/shootactivatorhidrogiga_at.bctex",
    "actors/props/shootactivatorhidrogiga/models/textures/shootactivatorhidrogiga_bc.bctex",
    "actors/props/shootactivatorhidrogiga/models/textures/shootactivatorhidrogiga_nm.bctex",
    "actors/props/shootactivatormag01/models/textures/shootactivatormag01_at.bctex",
    "actors/props/shootactivatormag01/models/textures/shootactivatormag01_bc.bctex",
    "actors/props/shootactivatormag01/models/textures/shootactivatormag01_nm.bctex",
    "actors/props/trap_thermal_horizontal/models/textures/thermaltrap_at.bctex",
    "actors/props/trap_thermal_horizontal/models/textures/thermaltrap_bc.bctex",
    "actors/props/trap_thermal_horizontal/models/textures/thermaltrap_nm.bctex",
    "actors/props/windpropeller/models/textures/windpropeller_at.bctex",
    "actors/props/windpropeller/models/textures/windpropeller_bc.bctex",
    "actors/props/windpropeller/models/textures/windpropeller_nm.bctex",
    "actors/props/zipline/models/textures/zipline_at.bctex",
    "actors/props/zipline/models/textures/zipline_bc.bctex",
    "actors/props/zipline/models/textures/zipline_nm.bctex",
    "actors/weapons/cooldownxbosswindtunneldamagetrigger/fx/textures/mask_hard.bctex",
    "actors/weapons/cooldownxbosswindtunneldamagetrigger/fx/textures/noise_clouds.bctex",
    "actors/weapons/icemissile/models/textures/icemissile_at.bctex",
    "actors/weapons/icemissile/models/textures/icemissile_bc.bctex",
    "actors/weapons/icemissile/models/textures/icemissile_nm.bctex",
    "actors/weapons/lockonmissile/models/textures/lockonmissile_at.bctex",
    "actors/weapons/lockonmissile/models/textures/lockonmissile_bc.bctex",
    "actors/weapons/lockonmissile/models/textures/lockonmissile_nm.bctex",
    "actors/weapons/missile/models/textures/missile_at.bctex",
    "actors/weapons/missile/models/textures/missile_bc.bctex",
    "actors/weapons/missile/models/textures/missile_nm.bctex",
    "actors/weapons/powerbeam/models/textures/noise_blured.bctex",
    "actors/weapons/powerbeam/models/textures/noise_directionalwaves.bctex",
    "actors/weapons/specialburst/models/textures/noise_base.bctex",
    "actors/weapons/specialburst/models/textures/noise_grunge.bctex",
    "actors/weapons/specialburst/models/textures/noise_grunge_intense.bctex",
    "actors/weapons/specialburst/models/textures/noise_soft.bctex",
    "actors/weapons/specialburst/models/textures/noise_vertical_energy.bctex",
    "actors/weapons/supermissile/models/textures/supermissile_at.bctex",
    "actors/weapons/supermissile/models/textures/supermissile_bc.bctex",
    "actors/weapons/supermissile/models/textures/supermissile_nm.bctex",
    "cutscenes/0057scorpiusdeath/fx/textures/ashesparticles3_anim_col.bctex",
    "cutscenes/0057scorpiusdeath/fx/textures/ashesparticles3_anim_pos.bctex",
    "cutscenes/0057scorpiusdeath/fx/textures/ashesparticles3_anim_pos2.bctex",
    "cutscenes/0057scorpiusdeath/fx/textures/ashesparticles4_anim_col.bctex",
    "cutscenes/0057scorpiusdeath/fx/textures/ashesparticles4_anim_pos.bctex",
    "cutscenes/0057scorpiusdeath/fx/textures/ashesparticles4_anim_pos2.bctex",
    "cutscenes/0057scorpiusdeath/fx/textures/smoke_grayscale_tiled_01.bctex",
    "cutscenes/0061kraiddeath/fx/textures/impact_decal_attributes.bctex",
    "cutscenes/0061kraiddeath/fx/textures/impact_decal_color.bctex",
    "cutscenes/0061kraiddeath/fx/textures/impact_decal_normal.bctex",
    "cutscenes/0061kraiddeath/fx/textures/kraid_decal_attributes.bctex",
    "cutscenes/0061kraiddeath/fx/textures/kraid_decal_color.bctex",
    "cutscenes/0061kraiddeath/fx/textures/kraid_decal_normal.bctex",
    "cutscenes/0081cooldowndeath/fx/textures/dissolve_ashes.bctex",
    "cutscenes/0081cooldowndeath/fx/textures/noise_cloudsgradient.bctex",
    "maps/cubemaps/19-8/emmy_v1diffusehdr.bctex",
    "maps/cubemaps/19-8/emmy_v1specularhdr.bctex",
    "maps/cubemaps/20_11/vrr.emmydiffusehdr.bctex",
    "maps/cubemaps/20_11/vrr.emmyspecularhdr.bctex",
    "maps/cubemaps/definitivos/e.2diffusehdr.bctex",
    "maps/cubemaps/definitivos/e.2specularhdr.bctex",
    "maps/cubemaps/definitivos/fr.1diffusehdr.bctex",
    "maps/cubemaps/definitivos/fr.1specularhdr.bctex",
    "maps/cubemaps/definitivos/fr.2_cave_versiondiffusehdr.bctex",
    "maps/cubemaps/definitivos/fr.2_cave_versionspecularhdr.bctex",
    "maps/cubemaps/definitivos/fr.2_quarantine_versiondiffusehdr.bctex",
    "maps/cubemaps/definitivos/fr.2_quarantine_versionspecularhdr.bctex",
    "maps/cubemaps/definitivos/fr.2diffusehdr.bctex",
    "maps/cubemaps/definitivos/fr.2specularhdr.bctex",
    "maps/cubemaps/definitivos/magma_outsidediffusehdr.bctex",
    "maps/cubemaps/definitivos/magma_outsidespecularhdr.bctex",
    "maps/cubemaps/glass_reflectionspecularhdr.bctex",
    "maps/cubemaps/tomoco_mirrorspecularhdr.bctex",
    "maps/cubemaps/water_statuespecularhdr.bctex",
    "maps/fx/amoebaparticles00/textures/amoebas00.bctex",
    "maps/fx/aquabubbles/textures/bubbles02.bctex",
    "maps/fx/aquabubbles/textures/bubbles03.bctex",
    "maps/fx/aquabubbles/textures/bubblesx4.bctex",
    "maps/fx/aquabubbles/textures/ramp01.bctex",
    "maps/fx/chozonumbers/fx/textures/chozo_seven.bctex",
    "maps/fx/chozonumbers/fx/textures/glow_long.bctex",
    "maps/fx/cloudlightning/textures/cloud00_lightdir.bctex",
    "maps/fx/cloudlightning/textures/cloud00_lightinner.bctex",
    "maps/fx/dustcorner00/fx/textures/dustfalling03.bctex",
    "maps/fx/emmymist00/fx/textures/gasmist00.bctex",
    "maps/fx/emmyventilationgridgas00/fx/textures/gasleak00.bctex",
    "maps/fx/lavasplashes/textures/lava_explosion00_anim_pos.bctex",
    "maps/fx/lavasplashes/textures/lava_explosion00_anim_pos2.bctex",
    "maps/fx/lavasplashes/textures/lava_explosion01_anim_pos.bctex",
    "maps/fx/lavasplashes/textures/lava_explosion01_anim_pos2.bctex",
    "maps/fx/lavasplashes/textures/lava_explosion02_anim_pos.bctex",
    "maps/fx/lavasplashes/textures/lava_explosion02_anim_pos2.bctex",
    "maps/fx/lightningstroke/textures/lightning_stroke_02.bctex",
    "maps/fx/liquidalongpipes/textures/bubblespipe_00.bctex",
    "maps/fx/pipeleaks00/fx/textures/alpha_ramp.bctex",
    "maps/fx/resin/textures/resin_nor.bctex",
    "maps/fx/resin/textures/resin_pos.bctex",
    "maps/fx/resin/textures/resin_pos2.bctex",
    "maps/fx/resin/textures/resinhorizontal_nor.bctex",
    "maps/fx/resin/textures/resinhorizontal_pos.bctex",
    "maps/fx/resin/textures/resinhorizontal_pos2.bctex",
    "maps/fx/splash00/fx/textures/splash04.bctex",
    "maps/fx/splashes/textures/splashes_waterfall.bctex",
    "maps/fx/sporesparticles00/textures/spores00.bctex",
    "maps/fx/waterstream/textures/waterstream00_ramp.bctex",
    "maps/fx/waterstream/textures/waterstream01_norm.bctex",
    "maps/fx/waterstream/textures/waterstream01_pos.bctex",
    "maps/fx/waterstream/textures/waterstream01_pos2.bctex",
    "maps/lightspots/caustic.bctex",
    "maps/lightspots/roundfan01_lspots.bctex",
    "maps/objects/cavewater00/textures/droplet.bctex",
    "maps/objects/cavewater00/textures/water_effluent.bctex",
    "maps/objects/chozoallcorner01a/textures/chozoallcorner01a_bc.bctex",
    "maps/objects/chozoallcorner01a/textures/chozoallcorner01a_nm.bctex",
    "maps/objects/chozoallcorner01b/textures/chozoallcorner01b_bc.bctex",
    "maps/objects/chozoallcorner01b/textures/chozoallcorner01b_nm.bctex",
    "maps/objects/chozoallpath01x1/textures/chozoallpath01x1_bc.bctex",
    "maps/objects/chozoallpath01x1/textures/chozoallpath01x1_nm.bctex",
    "maps/objects/chozoallpath01x3/textures/chozoallpath01x3_bc.bctex",
    "maps/objects/chozoallpath01x3/textures/chozoallpath01x3_nm.bctex",
    "maps/objects/chozoallwall01x1/textures/chozoallwall01x1_bc.bctex",
    "maps/objects/chozoallwall01x1/textures/chozoallwall01x1_nm.bctex",
    "maps/objects/chozoallwall01x3/textures/chozoallwall01x03_bc.bctex",
    "maps/objects/chozoallwall01x3/textures/chozoallwall01x03_nm.bctex",
    "maps/objects/fxwaterfallcave01/textures/waterfall_noise.bctex",
    "maps/textures/aqua_background_01_bc.bctex",
    "maps/textures/aquadigrock01_bc.bctex",
    "maps/textures/aquadigrock01_nm.bctex",
    "maps/textures/aquadigrock02_bc.bctex",
    "maps/textures/aquadigrock02_nm.bctex",
    "maps/textures/aquadigrock03_bc.bctex",
    "maps/textures/aquadigrock03_nm.bctex",
    "maps/textures/aquadigrock04_bc.bctex",
    "maps/textures/aquadigrock04_nm.bctex",
    "maps/textures/aquanature01_bc.bctex",
    "maps/textures/aquanature01_nm.bctex",
    "maps/textures/aquanature04_bc.bctex",
    "maps/textures/aquanature04_nm.bctex",
    "maps/textures/aquanature06_nm.bctex",
    "maps/textures/aquanature06b_bc.bctex",
    "maps/textures/aquarockplatform01x3_at.bctex",
    "maps/textures/aquarockplatform01x3_bc.bctex",
    "maps/textures/aquarockplatform01x3_nm.bctex",
    "maps/textures/baseat_at.bctex",
    "maps/textures/basenormal_nm.bctex",
    "maps/textures/cavedigrock02_bc.bctex",
    "maps/textures/cavedigrock02_nm.bctex",
    "maps/textures/cavedigrock04_bc.bctex",
    "maps/textures/cavedigrock04_nm.bctex",
    "maps/textures/cavegg01_at.bctex",
    "maps/textures/cavegg01_bc.bctex",
    "maps/textures/cavegg01_nm.bctex",
    "maps/textures/caverockborder_bc.bctex",
    "maps/textures/caverockborder_nm.bctex",
    "maps/textures/caverockplatform05_bc.bctex",
    "maps/textures/caverockplatform05_nm.bctex",
    "maps/textures/cavpathrock01_at.bctex",
    "maps/textures/cavpathrock01_bc.bctex",
    "maps/textures/cavpathrock01_nm.bctex",
    "maps/textures/cavpathrock01v2_at.bctex",
    "maps/textures/cavpathrock01v2_bc.bctex",
    "maps/textures/cavpathrock01v2_nm.bctex",
    "maps/textures/cavpathrock01v3_at.bctex",
    "maps/textures/cavpathrock01v3_bc.bctex",
    "maps/textures/cavpathrock01v3_nm.bctex",
    "maps/textures/cavpathrock01v4_at.bctex",
    "maps/textures/cavpathrock01v4_bc.bctex",
    "maps/textures/cavpathrock01v4_nm.bctex",
    "maps/textures/cavpathrock01v5_at.bctex",
    "maps/textures/cavpathrock01v5_bc.bctex",
    "maps/textures/cavpathrock01v5_nm.bctex",
    "maps/textures/cavplatformrock04v5_at.bctex",
    "maps/textures/cavplatformrock04v5_bc.bctex",
    "maps/textures/cavplatformrock04v5_nm.bctex",
    "maps/textures/cavplatformrock04v6_at.bctex",
    "maps/textures/cavplatformrock04v6_bc.bctex",
    "maps/textures/cavplatformrock04v6_nm.bctex",
    "maps/textures/cavrockbackground03_at.bctex",
    "maps/textures/cavrockbackground03_bc.bctex",
    "maps/textures/cavrockbackground03_nm.bctex",
    "maps/textures/cavrockbackground05_at.bctex",
    "maps/textures/cavrockbackground05_bc.bctex",
    "maps/textures/cavrockbackground05_nm.bctex",
    "maps/textures/cavrockbackground06_at.bctex",
    "maps/textures/cavrockbackground06_bc.bctex",
    "maps/textures/cavrockbackground06_nm.bctex",
    "maps/textures/cavrockbackground07_at.bctex",
    "maps/textures/cavrockbackground07_bc.bctex",
    "maps/textures/cavrockbackground07_nm.bctex",
    "maps/textures/cavrockbackground08_bc.bctex",
    "maps/textures/cavrockbackground17_bc.bctex",
    "maps/textures/cavrockbackground17_nm.bctex",
    "maps/textures/cavrockbackground27_bc.bctex",
    "maps/textures/cavrockbackground27_nm.bctex",
    "maps/textures/cavscorpiusbones_bc.bctex",
    "maps/textures/cavscorpiusbones_nm.bctex",
    "maps/textures/cavstatuesaveroom01_at.bctex",
    "maps/textures/cavstatuesaveroom01_bc.bctex",
    "maps/textures/cavstatuesaveroom01_nm.bctex",
    "maps/textures/cavstatuespecialboss01_at.bctex",
    "maps/textures/cavstatuespecialboss01_bc.bctex",
    "maps/textures/cavstatuespecialboss01_nm.bctex",
    "maps/textures/cavstatuespecialboss02_at.bctex",
    "maps/textures/cavstatuespecialboss02_bc.bctex",
    "maps/textures/cavstatuespecialboss02_nm.bctex",
    "maps/textures/checkergrey01_at.bctex",
    "maps/textures/checkergrey01_bc.bctex",
    "maps/textures/checkergrey01_nm.bctex",
    "maps/textures/checkergrey02_bc.bctex",
    "maps/textures/chozoallassetbox01_bc.bctex",
    "maps/textures/chozoallassetbox01_nm.bctex",
    "maps/textures/chozoallassetpanel_bc.bctex",
    "maps/textures/chozoallassetpanel_nm.bctex",
    "maps/textures/chozoallassettube01_bc.bctex",
    "maps/textures/chozoallassettube01_nm.bctex",
    "maps/textures/chozoallbgemmy01cornice_bc.bctex",
    "maps/textures/chozoallbgemmy01cornice_nm.bctex",
    "maps/textures/chozoallbgemmy01set03_nm.bctex",
    "maps/textures/chozoallbgemmy01set05_nm.bctex",
    "maps/textures/chozoallpathceiling01_bc.bctex",
    "maps/textures/chozoallpathceiling01_nm.bctex",
    "maps/textures/chozoallpathceiling02_bc.bctex",
    "maps/textures/chozoallpathceiling02_nm.bctex",
    "maps/textures/chozoallscaffold01_bc.bctex",
    "maps/textures/chozoallscaffold01_nm.bctex",
    "maps/textures/chozoaqatrezzofloorbg02_bc.bctex",
    "maps/textures/chozoaqatrezzofloorbg02_nm.bctex",
    "maps/textures/chozoaqatrezzoroofbg02_bc.bctex",
    "maps/textures/chozoaqatrezzoroofbg02_nm.bctex",
    "maps/textures/chozoaqbg_at.bctex",
    "maps/textures/chozoaqbg_bc.bctex",
    "maps/textures/chozoaqbg_nm.bctex",
    "maps/textures/chozoaqbgcorridor01_bc.bctex",
    "maps/textures/chozoaqbgcorridor01_nm.bctex",
    "maps/textures/chozoaqbggate01_bc.bctex",
    "maps/textures/chozoaqbggate01_nm.bctex",
    "maps/textures/chozoaqcorridor_at.bctex",
    "maps/textures/chozoaqcorridor_bc.bctex",
    "maps/textures/chozoaqcorridor_nm.bctex",
    "maps/textures/chozoaqpath05x1_bc.bctex",
    "maps/textures/chozoaqpath05x1_nm.bctex",
    "maps/textures/chozoaqpath05x4_bc.bctex",
    "maps/textures/chozoaqpath05x4_nm.bctex",
    "maps/textures/chozoaqplatform01_bc.bctex",
    "maps/textures/chozoaqplatform01_nm.bctex",
    "maps/textures/chozobgair_at.bctex",
    "maps/textures/chozobgair_bc.bctex",
    "maps/textures/chozobgair_nm.bctex",
    "maps/textures/chozoborderemmy01_nm.bctex",
    "maps/textures/chozoborderemmy02_bc.bctex",
    "maps/textures/chozodebriswall01_bc.bctex",
    "maps/textures/chozodebriswall01_nm.bctex",
    "maps/textures/chozodecal010_at.bctex",
    "maps/textures/chozodecal010_bc.bctex",
    "maps/textures/chozodecal010_nm.bctex",
    "maps/textures/chozodecal05_at.bctex",
    "maps/textures/chozodecal05_bc.bctex",
    "maps/textures/chozodecal05_nm.bctex",
    "maps/textures/chozodecal08_at.bctex",
    "maps/textures/chozodecal08_nm.bctex",
    "maps/textures/chozodecal08b_bc.bctex",
    "maps/textures/chozodecal09_at.bctex",
    "maps/textures/chozodecal09_bc.bctex",
    "maps/textures/chozodecal09_nm.bctex",
    "maps/textures/chozoemmybg01set03_bc.bctex",
    "maps/textures/chozoemmybg01set05_bc.bctex",
    "maps/textures/chozoemmypath01_bc.bctex",
    "maps/textures/chozoemmypath01x4_bc.bctex",
    "maps/textures/chozoemmytunnelbg01_bc.bctex",
    "maps/textures/chozoemmytunnelbg01_nm.bctex",
    "maps/textures/chozoemmywall01_bc.bctex",
    "maps/textures/chozoemmywall01_nm.bctex",
    "maps/textures/chozoemmywall02_bc.bctex",
    "maps/textures/chozoemmywall02_nm.bctex",
    "maps/textures/chozoforestbg01_bc.bctex",
    "maps/textures/chozoforestbg01_nm.bctex",
    "maps/textures/chozoforestpathwood01x2v2_bc.bctex",
    "maps/textures/chozoforestpathwood01x2v2_nm.bctex",
    "maps/textures/chozoforestpathwood01x4v1_bc.bctex",
    "maps/textures/chozoforestpathwood01x4v1_nm.bctex",
    "maps/textures/chozomagemmypath01_bc.bctex",
    "maps/textures/chozomagemmypath01_nm.bctex",
    "maps/textures/chozomatcircuits01_at.bctex",
    "maps/textures/chozomatcircuits01_bc.bctex",
    "maps/textures/chozomatcircuits01_nm.bctex",
    "maps/textures/chozomatcircuits04_at.bctex",
    "maps/textures/chozomatcircuits04_bc.bctex",
    "maps/textures/chozomatcircuits04_nm.bctex",
    "maps/textures/chozomatconcretebase01_at.bctex",
    "maps/textures/chozomatconcretebase01_bc.bctex",
    "maps/textures/chozomatconcretebase01_nm.bctex",
    "maps/textures/chozomatconcreteblue01_bc.bctex",
    "maps/textures/chozomatconcreteblue02_bc.bctex",
    "maps/textures/chozomatconcreteblue06_bc.bctex",
    "maps/textures/chozomatconcreteblue07_bc.bctex",
    "maps/textures/chozomatconcreteblue13_at.bctex",
    "maps/textures/chozomatconcreteblue13_bc.bctex",
    "maps/textures/chozomatconcreteblue13_nm.bctex",
    "maps/textures/chozomatconcreteblue14_at.bctex",
    "maps/textures/chozomatconcreteblue14_bc.bctex",
    "maps/textures/chozomatconcreteblue14_nm.bctex",
    "maps/textures/chozomatconcretegray02_at.bctex",
    "maps/textures/chozomatconcretegray02_bc.bctex",
    "maps/textures/chozomatconcretegray02_nm.bctex",
    "maps/textures/chozomatconcretegray04_at.bctex",
    "maps/textures/chozomatconcretegray04_bc.bctex",
    "maps/textures/chozomatconcretegray04_nm.bctex",
    "maps/textures/chozomatconcretegreen01_at.bctex",
    "maps/textures/chozomatconcretegreen01_bc.bctex",
    "maps/textures/chozomatconcretegreen01_nm.bctex",
    "maps/textures/chozomatconcretepattern04_at.bctex",
    "maps/textures/chozomatconcretepattern04_bc.bctex",
    "maps/textures/chozomatconcretepattern04_nm.bctex",
    "maps/textures/chozomatconcretepurple01_at.bctex",
    "maps/textures/chozomatconcretepurple01_bc.bctex",
    "maps/textures/chozomatconcretepurple01_nm.bctex",
    "maps/textures/chozomatemissive01_at.bctex",
    "maps/textures/chozomatemissive01_bc.bctex",
    "maps/textures/chozomatemissive01_nm.bctex",
    "maps/textures/chozomatflatblack01_bc.bctex",
    "maps/textures/chozomatflatblack02_bc.bctex",
    "maps/textures/chozomatflatblack02_nm.bctex",
    "maps/textures/chozomatflatblack03_bc.bctex",
    "maps/textures/chozomatflatblack03_nm.bctex",
    "maps/textures/chozomatflatblack04_bc.bctex",
    "maps/textures/chozomatflatblack05_bc.bctex",
    "maps/textures/chozomatflatblack05_nm.bctex",
    "maps/textures/chozomatflatblue01_bc.bctex",
    "maps/textures/chozomatflatblue01_nm.bctex",
    "maps/textures/chozomatmetalblack01_at.bctex",
    "maps/textures/chozomatmetalblack01_bc.bctex",
    "maps/textures/chozomatmetalblack01_nm.bctex",
    "maps/textures/chozomatmetalblue02_bc.bctex",
    "maps/textures/chozomatmetalblue02_nm.bctex",
    "maps/textures/chozomatmetalblue03_bc.bctex",
    "maps/textures/chozomatmetalblue03_nm.bctex",
    "maps/textures/chozomatmetalblue04_bc.bctex",
    "maps/textures/chozomatmetalblue04_nm.bctex",
    "maps/textures/chozomatmetalblue06_bc.bctex",
    "maps/textures/chozomatmetalblue06_nm.bctex",
    "maps/textures/chozomatmetalblue09_bc.bctex",
    "maps/textures/chozomatmetalblue09_nm.bctex",
    "maps/textures/chozomatmetalblue11_bc.bctex",
    "maps/textures/chozomatmetalblue11_nm.bctex",
    "maps/textures/chozomatmetalbrown01_at.bctex",
    "maps/textures/chozomatmetalbrown01_bc.bctex",
    "maps/textures/chozomatmetalbrown01_nm.bctex",
    "maps/textures/chozomatmetalbrown02_at.bctex",
    "maps/textures/chozomatmetalbrown02_bc.bctex",
    "maps/textures/chozomatmetalbrown02_nm.bctex",
    "maps/textures/chozomatmetalbrown03_at.bctex",
    "maps/textures/chozomatmetalbrown03_bc.bctex",
    "maps/textures/chozomatmetalbrown03_nm.bctex",
    "maps/textures/chozomatmetalbrown04_at.bctex",
    "maps/textures/chozomatmetalbrown04_bc.bctex",
    "maps/textures/chozomatmetalbrown04_nm.bctex",
    "maps/textures/chozomatmetalbrown05_bc.bctex",
    "maps/textures/chozomatmetalbrown05_nm.bctex",
    "maps/textures/chozomatmetalbrown09_bc.bctex",
    "maps/textures/chozomatmetalbrown09_nm.bctex",
    "maps/textures/chozomatmetalgray01_at.bctex",
    "maps/textures/chozomatmetalgray01_bc.bctex",
    "maps/textures/chozomatmetalgray01_nm.bctex",
    "maps/textures/chozomatmetalgray02_at.bctex",
    "maps/textures/chozomatmetalgray02_bc.bctex",
    "maps/textures/chozomatmetalgray02_nm.bctex",
    "maps/textures/chozomatmetalgray03_at.bctex",
    "maps/textures/chozomatmetalgray03_bc.bctex",
    "maps/textures/chozomatmetalgray03_nm.bctex",
    "maps/textures/chozomatmetalgray04_at.bctex",
    "maps/textures/chozomatmetalgray04_bc.bctex",
    "maps/textures/chozomatmetalgray04_nm.bctex",
    "maps/textures/chozomatmetalgray05_bc.bctex",
    "maps/textures/chozomatmetalgray09_bc.bctex",
    "maps/textures/chozomatmetalgray09_nm.bctex",
    "maps/textures/chozomatmetalgray10_bc.bctex",
    "maps/textures/chozomatmetalgray10_nm.bctex",
    "maps/textures/chozomatmetalgray11_bc.bctex",
    "maps/textures/chozomatmetalgray12_bc.bctex",
    "maps/textures/chozomatmetalgray12_nm.bctex",
    "maps/textures/chozomatmetalgray15_bc.bctex",
    "maps/textures/chozomatmetalgray15_nm.bctex",
    "maps/textures/chozomatmetalgreen01_at.bctex",
    "maps/textures/chozomatmetalgreen01_bc.bctex",
    "maps/textures/chozomatmetalgreen01_nm.bctex",
    "maps/textures/chozomatmetalgreen03_at.bctex",
    "maps/textures/chozomatmetalgreen03_bc.bctex",
    "maps/textures/chozomatmetalgreen03_nm.bctex",
    "maps/textures/chozomatmetalgreen08_bc.bctex",
    "maps/textures/chozomatmetalgreen08_nm.bctex",
    "maps/textures/chozomatmetalred01_bc.bctex",
    "maps/textures/chozomatmetalred01_nm.bctex",
    "maps/textures/chozomatmetalred03_bc.bctex",
    "maps/textures/chozomatmetalred03_nm.bctex",
    "maps/textures/chozomatmetalred04_bc.bctex",
    "maps/textures/chozomatmetalred04_nm.bctex",
    "maps/textures/chozomatmetalred05_bc.bctex",
    "maps/textures/chozomatmetalred05_nm.bctex",
    "maps/textures/chozomatmetalwhite01_bc.bctex",
    "maps/textures/chozomatmetalwhite02_at.bctex",
    "maps/textures/chozomatmetalwhite02_bc.bctex",
    "maps/textures/chozomatmetalwhite02_nm.bctex",
    "maps/textures/chozomatmetalwhite03_bc.bctex",
    "maps/textures/chozomatmetalwhite03_nm.bctex",
    "maps/textures/chozomatmetalwhite05_bc.bctex",
    "maps/textures/chozomatmetalwhite06_bc.bctex",
    "maps/textures/chozomatmetalwhite06_nm.bctex",
    "maps/textures/chozomatmetalyellow02_bc.bctex",
    "maps/textures/chozomatpaintedwhite01_bc.bctex",
    "maps/textures/chozomatpaintedwhite01_nm.bctex",
    "maps/textures/chozomatpaintedyellow02_bc.bctex",
    "maps/textures/chozomatpaintedyellow02_nm.bctex",
    "maps/textures/chozomatpipes01_bc.bctex",
    "maps/textures/chozomatpipes01_nm.bctex",
    "maps/textures/chozomatpipes02_at.bctex",
    "maps/textures/chozomatpipes02_bc.bctex",
    "maps/textures/chozomatpipes02_nm.bctex",
    "maps/textures/chozomatpipes10_bc.bctex",
    "maps/textures/chozomatpipes12_bc.bctex",
    "maps/textures/chozomatpipes12_nm.bctex",
    "maps/textures/chozomatpipes13_bc.bctex",
    "maps/textures/chozomatpipes13_nm.bctex",
    "maps/textures/chozomatpipes15_at.bctex",
    "maps/textures/chozomatpipes15_bc.bctex",
    "maps/textures/chozomatpipes15_nm.bctex",
    "maps/textures/chozomatplates03_bc.bctex",
    "maps/textures/chozomatplates03_nm.bctex",
    "maps/textures/chozomatplates06_at.bctex",
    "maps/textures/chozomatplates06_bc.bctex",
    "maps/textures/chozomatplates06_nm.bctex",
    "maps/textures/chozopathemmy01_nm.bctex",
    "maps/textures/chozopathemmy01x4_nm.bctex",
    "maps/textures/chozopathemmy02_at.bctex",
    "maps/textures/chozopathemmy02_bc.bctex",
    "maps/textures/chozopathemmy02_nm.bctex",
    "maps/textures/chozopathemmy02x4_bc.bctex",
    "maps/textures/chozopathemmy02x4_nm.bctex",
    "maps/textures/chozopathgeneric01_bc.bctex",
    "maps/textures/chozopathgeneric01_nm.bctex",
    "maps/textures/chozosancbasestatue01_bc.bctex",
    "maps/textures/chozosancbg04_bc.bctex",
    "maps/textures/chozosancfullflag01alpha_at.bctex",
    "maps/textures/chozosancfullflag01alpha_bc.bctex",
    "maps/textures/chozosancfullflag01alpha_nm.bctex",
    "maps/textures/chozosancfullflag01alphafx_nm.bctex",
    "maps/textures/chozosancfullflag01base_nm.bctex",
    "maps/textures/chozosancfullflag01basefx_nm.bctex",
    "maps/textures/chozosanclamp_bc.bctex",
    "maps/textures/chozosanclamp_nm.bctex",
    "maps/textures/chozosancnest02_bc.bctex",
    "maps/textures/chozosancnest02_nm.bctex",
    "maps/textures/chozosancnest03_bc.bctex",
    "maps/textures/chozosancnest03_nm.bctex",
    "maps/textures/chozosancpath_bc.bctex",
    "maps/textures/chozosancpath_nm.bctex",
    "maps/textures/chozosancsidewall01_bc.bctex",
    "maps/textures/chozosancsidewall02_bc.bctex",
    "maps/textures/chozosancstatuebig01_bc.bctex",
    "maps/textures/chozosancstatuebig01_nm.bctex",
    "maps/textures/chozosancstatuebig02_bc.bctex",
    "maps/textures/chozosancstatuebig02_nm.bctex",
    "maps/textures/chozosancwall01_bc.bctex",
    "maps/textures/chozosancwall01_nm.bctex",
    "maps/textures/chozoskybasecontroldesk01_at.bctex",
    "maps/textures/chozoskybasecontroldesk01_bc.bctex",
    "maps/textures/chozoskybasecontroldesk01_nm.bctex",
    "maps/textures/chozoskybasestatue01_bc.bctex",
    "maps/textures/chozoskybasestatue01_nm.bctex",
    "maps/textures/chozoskybasestatue02_bc.bctex",
    "maps/textures/chozoskybasestatue02_nm.bctex",
    "maps/textures/chozoskypath_bc.bctex",
    "maps/textures/chozoskypath_nm.bctex",
    "maps/textures/chozoskypathroof01_bc.bctex",
    "maps/textures/chozoskypathroof01_nm.bctex",
    "maps/textures/chozoskypathroof02_bc.bctex",
    "maps/textures/chozoskypathroof02_nm.bctex",
    "maps/textures/chozoskypathroofx01_bc.bctex",
    "maps/textures/chozoskypathroofx01_nm.bctex",
    "maps/textures/chozoskypathroofx02_bc.bctex",
    "maps/textures/chozoskypathroofx02_nm.bctex",
    "maps/textures/chozoskypathroofx03_bc.bctex",
    "maps/textures/chozoskypathroofx03_nm.bctex",
    "maps/textures/chozosteelplates_bc.bctex",
    "maps/textures/chozosteelplates_nm.bctex",
    "maps/textures/concretegreen01_at.bctex",
    "maps/textures/concretegreen01_bc.bctex",
    "maps/textures/concretegreen01_nm.bctex",
    "maps/textures/cooldownmachinesnot_nm.bctex",
    "maps/textures/debuggrey01_bc.bctex",
    "maps/textures/forestdigrock03_bc.bctex",
    "maps/textures/forestdigrock03_nm.bctex",
    "maps/textures/forestgoundwet02_bc.bctex",
    "maps/textures/forestgoundwet02_nm.bctex",
    "maps/textures/forestmoss02_bc.bctex",
    "maps/textures/forestmoss02_nm.bctex",
    "maps/textures/forestmoss03_bc.bctex",
    "maps/textures/forestmoss03_nm.bctex",
    "maps/textures/forestplantscales_bc.bctex",
    "maps/textures/forestplantscales_nm.bctex",
    "maps/textures/forestrock01_bc.bctex",
    "maps/textures/forestrock01_nm.bctex",
    "maps/textures/forestrock02_bc.bctex",
    "maps/textures/forestrock02_nm.bctex",
    "maps/textures/forestrock03_bc.bctex",
    "maps/textures/forestrock03_nm.bctex",
    "maps/textures/forestrock04_bc.bctex",
    "maps/textures/forestrock04_nm.bctex",
    "maps/textures/foresttreeskin01_bc.bctex",
    "maps/textures/foresttreeskin01_nm.bctex",
    "maps/textures/forestwallarenaboss_bc.bctex",
    "maps/textures/forestwallarenaboss_nm.bctex",
    "maps/textures/gobo_leafs.bctex",
    "maps/textures/grass01_bc.bctex",
    "maps/textures/grass01_nm.bctex",
    "maps/textures/grassleaves05_bc.bctex",
    "maps/textures/hitdemolitionblock02_at.bctex",
    "maps/textures/hitdemolitionblock02_bc.bctex",
    "maps/textures/hitdemolitionblock02_nm.bctex",
    "maps/textures/ice_surface.bctex",
    "maps/textures/icebase_bc.bctex",
    "maps/textures/icebase_nm.bctex",
    "maps/textures/lavamat01_bc.bctex",
    "maps/textures/lavamat04_at.bctex",
    "maps/textures/lavamat04_bc.bctex",
    "maps/textures/lavamat04_nm.bctex",
    "maps/textures/lighshaftbase_bc.bctex",
    "maps/textures/lighshaftbase_lamp.bctex",
    "maps/textures/lighshaftdust_bc.bctex",
    "maps/textures/lightshaft_smoke.bctex",
    "maps/textures/magdigrocklava_bc.bctex",
    "maps/textures/magdigrocklava_nm.bctex",
    "maps/textures/magdigrockplatformlava01_bc.bctex",
    "maps/textures/magdigrockplatformlava01_nm.bctex",
    "maps/textures/magmeltrock02_bc.bctex",
    "maps/textures/magmeltrock02_nm.bctex",
    "maps/textures/magnetglovesp01_at.bctex",
    "maps/textures/magnetglovesp01_bc.bctex",
    "maps/textures/magnetglovesp01_nm.bctex",
    "maps/textures/magnetzipline_at.bctex",
    "maps/textures/magnetzipline_bc.bctex",
    "maps/textures/magnetzipline_nm.bctex",
    "maps/textures/magrockborder_bc.bctex",
    "maps/textures/magrockborder_nm.bctex",
    "maps/textures/mapsdust.bctex",
    "maps/textures/marbleblue02_bc.bctex",
    "maps/textures/mattepaintingcooldownxrocks_bc.bctex",
    "maps/textures/mattepaintingcooldownxskybox_bc.bctex",
    "maps/textures/mattepaintingforest019background01_bc.bctex",
    "maps/textures/mattepaintingsanctuary004background01_bc.bctex",
    "maps/textures/mattepaintingsanctuary004rocks01_bc.bctex",
    "maps/textures/mattepaintingshipyard006sky01_bc.bctex",
    "maps/textures/mattepaintingshipyard006sky02_bc.bctex",
    "maps/textures/mattepaintingshipyard007sky01_bc.bctex",
    "maps/textures/moss_generic_nm.bctex",
    "maps/textures/mossdecal04_at.bctex",
    "maps/textures/mossdecal04_bc.bctex",
    "maps/textures/mossdecal04_nm.bctex",
    "maps/textures/mudmatcave07_bc.bctex",
    "maps/textures/mudmatcave07_nm.bctex",
    "maps/textures/mudmatcave08_bc.bctex",
    "maps/textures/mudmatcave08_nm.bctex",
    "maps/textures/mudmatcave09_bc.bctex",
    "maps/textures/mudmatcave09_nm.bctex",
    "maps/textures/noise.bctex",
    "maps/textures/noise_magnet.bctex",
    "maps/textures/plantforestblue_bc.bctex",
    "maps/textures/plantforesthongo_at.bctex",
    "maps/textures/plantforesthongo_bc.bctex",
    "maps/textures/plantforesthongo_nm.bctex",
    "maps/textures/plantforestminis_at.bctex",
    "maps/textures/plantforestminis_bc.bctex",
    "maps/textures/plantforestminis_nm.bctex",
    "maps/textures/plantforestorganictree_at.bctex",
    "maps/textures/plantforestorganictree_bc.bctex",
    "maps/textures/plantforestorganictree_nm.bctex",
    "maps/textures/platformcavewaterb_bc.bctex",
    "maps/textures/platformcavewaterb_nm.bctex",
    "maps/textures/rain01_bc.bctex",
    "maps/textures/redleave2_bc.bctex",
    "maps/textures/redleave2_nm.bctex",
    "maps/textures/rockforestplatform01x4v2_bc.bctex",
    "maps/textures/rockforestplatform01x4v2_nm.bctex",
    "maps/textures/rockforestplatform01x4v3_bc.bctex",
    "maps/textures/rockforestplatform01x4v3_nm.bctex",
    "maps/textures/sandbase01_bc.bctex",
    "maps/textures/sandbase01_nm.bctex",
    "maps/textures/sanddunes01_bc.bctex",
    "maps/textures/sanddunes01_nm.bctex",
    "maps/textures/shipyardrock01_bc.bctex",
    "maps/textures/shipyardrock01_nm.bctex",
    "maps/textures/shipyardrock02_bc.bctex",
    "maps/textures/shipyardrock02_nm.bctex",
    "maps/textures/shipyardrock03_bc.bctex",
    "maps/textures/shipyardrock03_nm.bctex",
    "maps/textures/shipyardrock06_bc.bctex",
    "maps/textures/shipyardrock06_nm.bctex",
    "maps/textures/skin04_bc.bctex",
    "maps/textures/skin04_nm.bctex",
    "maps/textures/skin05_bc.bctex",
    "maps/textures/skin05_nm.bctex",
    "maps/textures/skin08_at.bctex",
    "maps/textures/skin08_bc.bctex",
    "maps/textures/skin08_nm.bctex",
    "maps/textures/skin09_bc.bctex",
    "maps/textures/skin09_nm.bctex",
    "maps/textures/skybase_matte01.bctex",
    "maps/textures/skybase_matte02.bctex",
    "maps/textures/water_surface_2_nm.bctex",
    "maps/textures/water_surface_bubbles.bctex",
    "maps/textures/watermatfront01_bc.bctex",
    "maps/textures/watermattopt01_bc.bctex",
    "maps/textures/wavedetail2_bc.bctex",
    "maps/textures/wavedetail_bc.bctex",
    "maps/textures/waves01_nm.bctex",
    "maps/textures/woodbark03_bc.bctex",
    "maps/textures/woodbark03_nm.bctex",
    "maps/textures/woodbark04_bc.bctex",
    "maps/textures/woodbark04_nm.bctex",
    "maps/textures/woodbark05_bc.bctex",
    "maps/textures/woodbark05_nm.bctex",
    "system/dev/reflectioncubetest/cubechurch256.bctex",
    "system/fx/generic/textures/glow_band.bctex",
    "system/fx/generic/textures/noise_trails_soft.bctex",
    "system/fx/generic/textures/web_energy.bctex",
    "system/fx/textures/beamglow_l.bctex",
    "system/fx/textures/block_rgba.bctex",
    "system/fx/textures/clipray.bctex",
    "system/fx/textures/electricbound.bctex",
    "system/fx/textures/energyexplosion.bctex",
    "system/fx/textures/explosion.bctex",
    "system/fx/textures/explosion2.bctex",
    "system/fx/textures/flamelickanim_l.bctex",
    "system/fx/textures/glow3.bctex",
    "system/fx/textures/glow3_center.bctex",
    "system/fx/textures/glow4.bctex",
    "system/fx/textures/gradienth.bctex",
    "system/fx/textures/grapplebreak.bctex",
    "system/fx/textures/grapplebreak2.bctex",
    "system/fx/textures/halo2.bctex",
    "system/fx/textures/impact2.bctex",
    "system/fx/textures/leavessegments_l.bctex",
    "system/fx/textures/noisesmall_l.bctex",
    "system/fx/textures/smokewave.bctex",
    "system/fx/textures/soft.bctex",
    "system/fx/textures/sparks.bctex",
    "system/fx/textures/stones4_la.bctex",
    "system/fx/textures/tracer.bctex",
    "system/fx/textures/tracer2.bctex",
    "system/fx/textures/trail_l.bctex",
    "system/fx/textures_zdr/allwhite.bctex",
    "system/fx/textures_zdr/ash_small.bctex",
    "system/fx/textures_zdr/aura.bctex",
    "system/fx/textures_zdr/bnwspotsgradient.bctex",
    "system/fx/textures_zdr/bomb_prerays.bctex",
    "system/fx/textures_zdr/bomb_prerays_02.bctex",
    "system/fx/textures_zdr/brain_blood.bctex",
    "system/fx/textures_zdr/brain_particle.bctex",
    "system/fx/textures_zdr/brain_splash_02.bctex",
    "system/fx/textures_zdr/brain_splash_03.bctex",
    "system/fx/textures_zdr/brain_splash_04.bctex",
    "system/fx/textures_zdr/brainsplash_noisy.bctex",
    "system/fx/textures_zdr/bubble.bctex",
    "system/fx/textures_zdr/bubble_inside_splash.bctex",
    "system/fx/textures_zdr/bubble_splash.bctex",
    "system/fx/textures_zdr/bubbles_0.bctex",
    "system/fx/textures_zdr/bubbles_02.bctex",
    "system/fx/textures_zdr/camera_dust.bctex",
    "system/fx/textures_zdr/chozocommander_glow.bctex",
    "system/fx/textures_zdr/chozorobot_burst.bctex",
    "system/fx/textures_zdr/chozotrail_long.bctex",
    "system/fx/textures_zdr/circle.bctex",
    "system/fx/textures_zdr/circle_innernoise.bctex",
    "system/fx/textures_zdr/cloud.bctex",
    "system/fx/textures_zdr/cloud_02.bctex",
    "system/fx/textures_zdr/crack.bctex",
    "system/fx/textures_zdr/dashself.bctex",
    "system/fx/textures_zdr/debris_kraid.bctex",
    "system/fx/textures_zdr/debris_metalpiece.bctex",
    "system/fx/textures_zdr/debris_rocks_3x3.bctex",
    "system/fx/textures_zdr/debris_stone.bctex",
    "system/fx/textures_zdr/distortion_bigshaft.bctex",
    "system/fx/textures_zdr/distortion_heat.bctex",
    "system/fx/textures_zdr/distortion_laser.bctex",
    "system/fx/textures_zdr/distortion_paraboloid_rg.bctex",
    "system/fx/textures_zdr/distortion_ring_blurred_rg.bctex",
    "system/fx/textures_zdr/distortion_tile.bctex",
    "system/fx/textures_zdr/distortion_tile_16.bctex",
    "system/fx/textures_zdr/distortion_trilineal.bctex",
    "system/fx/textures_zdr/distortion_wave00.bctex",
    "system/fx/textures_zdr/distortion_wave02.bctex",
    "system/fx/textures_zdr/distortion_wave03.bctex",
    "system/fx/textures_zdr/distortion_wave_noise.bctex",
    "system/fx/textures_zdr/dust_01_single.bctex",
    "system/fx/textures_zdr/dust_01_tiled.bctex",
    "system/fx/textures_zdr/dust_grain.bctex",
    "system/fx/textures_zdr/dust_noise.bctex",
    "system/fx/textures_zdr/egg_saboturu.bctex",
    "system/fx/textures_zdr/energy_explosion_void.bctex",
    "system/fx/textures_zdr/energy_small.bctex",
    "system/fx/textures_zdr/energy_soft.bctex",
    "system/fx/textures_zdr/energy_soft_hole.bctex",
    "system/fx/textures_zdr/energy_soulcoaster.bctex",
    "system/fx/textures_zdr/explosion_big.bctex",
    "system/fx/textures_zdr/explosion_decal.bctex",
    "system/fx/textures_zdr/explosion_energy.bctex",
    "system/fx/textures_zdr/explosion_fire.bctex",
    "system/fx/textures_zdr/explosion_smoke.bctex",
    "system/fx/textures_zdr/explosion_spikes01.bctex",
    "system/fx/textures_zdr/fire.bctex",
    "system/fx/textures_zdr/fire_blue_01.bctex",
    "system/fx/textures_zdr/fire_end.bctex",
    "system/fx/textures_zdr/fire_flame.bctex",
    "system/fx/textures_zdr/fire_generic_bw.bctex",
    "system/fx/textures_zdr/fire_small.bctex",
    "system/fx/textures_zdr/flame_pink.bctex",
    "system/fx/textures_zdr/floor_blood.bctex",
    "system/fx/textures_zdr/gas_noise.bctex",
    "system/fx/textures_zdr/glow.bctex",
    "system/fx/textures_zdr/glow2.bctex",
    "system/fx/textures_zdr/glow_angle.bctex",
    "system/fx/textures_zdr/glow_big.bctex",
    "system/fx/textures_zdr/glow_noise.bctex",
    "system/fx/textures_zdr/glow_spiky.bctex",
    "system/fx/textures_zdr/glow_spiky_big.bctex",
    "system/fx/textures_zdr/glowangle.bctex",
    "system/fx/textures_zdr/goliath_trail.bctex",
    "system/fx/textures_zdr/ground_crack.bctex",
    "system/fx/textures_zdr/impact_decal.bctex",
    "system/fx/textures_zdr/impact_shaft.bctex",
    "system/fx/textures_zdr/impactshaft.bctex",
    "system/fx/textures_zdr/kraid_slime_hd.bctex",
    "system/fx/textures_zdr/lensflare.bctex",
    "system/fx/textures_zdr/lensflare_02.bctex",
    "system/fx/textures_zdr/lightning.bctex",
    "system/fx/textures_zdr/lightning_4.bctex",
    "system/fx/textures_zdr/lightning_slim.bctex",
    "system/fx/textures_zdr/lightning_slim_glow.bctex",
    "system/fx/textures_zdr/magma_small.bctex",
    "system/fx/textures_zdr/mlmtrail.bctex",
    "system/fx/textures_zdr/motiontrail.bctex",
    "system/fx/textures_zdr/muzzle_shot.bctex",
    "system/fx/textures_zdr/noise_clouds2.bctex",
    "system/fx/textures_zdr/noise_clouds3.bctex",
    "system/fx/textures_zdr/noise_cloudsblurred.bctex",
    "system/fx/textures_zdr/noise_gaussian.bctex",
    "system/fx/textures_zdr/noise_grunge002.bctex",
    "system/fx/textures_zdr/noise_organic000.bctex",
    "system/fx/textures_zdr/noise_round.bctex",
    "system/fx/textures_zdr/noise_soft_2.bctex",
    "system/fx/textures_zdr/noise_spykes.bctex",
    "system/fx/textures_zdr/noise_sticky.bctex",
    "system/fx/textures_zdr/noise_sticky_invert.bctex",
    "system/fx/textures_zdr/noise_sticky_invertblur.bctex",
    "system/fx/textures_zdr/noise_sticky_trail.bctex",
    "system/fx/textures_zdr/normalwaves.bctex",
    "system/fx/textures_zdr/object_shaft.bctex",
    "system/fx/textures_zdr/one_pixel.bctex",
    "system/fx/textures_zdr/one_pixel_tail.bctex",
    "system/fx/textures_zdr/particles_01.bctex",
    "system/fx/textures_zdr/piece1_at.bctex",
    "system/fx/textures_zdr/piece1_bc.bctex",
    "system/fx/textures_zdr/piece1_nm.bctex",
    "system/fx/textures_zdr/pieces_broken_paper_01.bctex",
    "system/fx/textures_zdr/plasma.bctex",
    "system/fx/textures_zdr/powerbeam_chargeball_rings.bctex",
    "system/fx/textures_zdr/powerbeam_chargeball_rings03.bctex",
    "system/fx/textures_zdr/powerbeam_charged_backglow.bctex",
    "system/fx/textures_zdr/powerbeam_charged_backtwist.bctex",
    "system/fx/textures_zdr/powerbeam_charged_bigglow.bctex",
    "system/fx/textures_zdr/powerbeam_charged_bigglow_vertical.bctex",
    "system/fx/textures_zdr/powerbeam_charged_bigglowflash.bctex",
    "system/fx/textures_zdr/powerbeam_charged_createball.bctex",
    "system/fx/textures_zdr/powerbeam_charged_lines.bctex",
    "system/fx/textures_zdr/powerbeam_charged_loopball_center.bctex",
    "system/fx/textures_zdr/powerbeam_charged_ringglow.bctex",
    "system/fx/textures_zdr/powerbeam_impact_charged_shaft_long.bctex",
    "system/fx/textures_zdr/powerbeam_impact_chargedcore.bctex",
    "system/fx/textures_zdr/powerbeam_impact_chargedcore2.bctex",
    "system/fx/textures_zdr/powerbeam_impact_chargedcore3.bctex",
    "system/fx/textures_zdr/powerbeam_impact_chargeddetail.bctex",
    "system/fx/textures_zdr/powerbeam_impact_chargeddetail02.bctex",
    "system/fx/textures_zdr/powerbeam_impact_chargeddetail_blured.bctex",
    "system/fx/textures_zdr/powerbeam_impact_shaft.bctex",
    "system/fx/textures_zdr/powerbeam_impact_splash.bctex",
    "system/fx/textures_zdr/powerbeam_shaft.bctex",
    "system/fx/textures_zdr/quetzoa_ball_impact_rays.bctex",
    "system/fx/textures_zdr/radial_shaft_butless.bctex",
    "system/fx/textures_zdr/ramp/ramp_fresnel.bctex",
    "system/fx/textures_zdr/ramp/ramp_samus.bctex",
    "system/fx/textures_zdr/ray_bigthin.bctex",
    "system/fx/textures_zdr/ray_radial.bctex",
    "system/fx/textures_zdr/ray_round.bctex",
    "system/fx/textures_zdr/rayarc_tile.bctex",
    "system/fx/textures_zdr/rayarc_tile04.bctex",
    "system/fx/textures_zdr/rayarc_tile_02.bctex",
    "system/fx/textures_zdr/rayarc_tile_03.bctex",
    "system/fx/textures_zdr/rays_air_line.bctex",
    "system/fx/textures_zdr/rays_alphalevels_01.bctex",
    "system/fx/textures_zdr/rays_alphalevels_02.bctex",
    "system/fx/textures_zdr/rays_ball_tiled.bctex",
    "system/fx/textures_zdr/rays_beam.bctex",
    "system/fx/textures_zdr/rays_line.bctex",
    "system/fx/textures_zdr/ring_gradient_blured.bctex",
    "system/fx/textures_zdr/ring_slim.bctex",
    "system/fx/textures_zdr/ringblured.bctex",
    "system/fx/textures_zdr/ringlines.bctex",
    "system/fx/textures_zdr/ringlines_blured.bctex",
    "system/fx/textures_zdr/ringnoise.bctex",
    "system/fx/textures_zdr/ringshaft_vel.bctex",
    "system/fx/textures_zdr/ringsharpen.bctex",
    "system/fx/textures_zdr/sentencesphere_ringlines.bctex",
    "system/fx/textures_zdr/shaft_animeline.bctex",
    "system/fx/textures_zdr/shaft_bigimpact.bctex",
    "system/fx/textures_zdr/shaft_fullscreen.bctex",
    "system/fx/textures_zdr/shaft_long.bctex",
    "system/fx/textures_zdr/shaft_radial.bctex",
    "system/fx/textures_zdr/shaft_radial_thin.bctex",
    "system/fx/textures_zdr/shaft_slimspykes.bctex",
    "system/fx/textures_zdr/shipyardlightning.bctex",
    "system/fx/textures_zdr/shipyardlightning02.bctex",
    "system/fx/textures_zdr/smoke_big.bctex",
    "system/fx/textures_zdr/smoke_burst.bctex",
    "system/fx/textures_zdr/smoke_circle.bctex",
    "system/fx/textures_zdr/smoke_dryice01.bctex",
    "system/fx/textures_zdr/smoke_generic.bctex",
    "system/fx/textures_zdr/smoke_generic_03.bctex",
    "system/fx/textures_zdr/smoke_generic_05.bctex",
    "system/fx/textures_zdr/smoke_generic_loop_00.bctex",
    "system/fx/textures_zdr/smoke_mid.bctex",
    "system/fx/textures_zdr/smoke_trail.bctex",
    "system/fx/textures_zdr/smoke_wave.bctex",
    "system/fx/textures_zdr/smokefront_hd.bctex",
    "system/fx/textures_zdr/smokestomp01.bctex",
    "system/fx/textures_zdr/smokewallfront.bctex",
    "system/fx/textures_zdr/snowflake.bctex",
    "system/fx/textures_zdr/specialburst_backburst_center.bctex",
    "system/fx/textures_zdr/specialburst_ball.bctex",
    "system/fx/textures_zdr/specialrocket_airwave2.bctex",
    "system/fx/textures_zdr/specialrocket_burst_waves.bctex",
    "system/fx/textures_zdr/specialrocket_impactblockwave.bctex",
    "system/fx/textures_zdr/specialrocket_impactenergybig.bctex",
    "system/fx/textures_zdr/specialrocket_impactenergybig2.bctex",
    "system/fx/textures_zdr/specialrocket_impactsouls.bctex",
    "system/fx/textures_zdr/sphere_shaft.bctex",
    "system/fx/textures_zdr/sphereenergy_var.bctex",
    "system/fx/textures_zdr/sphereenergynoise.bctex",
    "system/fx/textures_zdr/splash_01.bctex",
    "system/fx/textures_zdr/stickysplashes_2x2.bctex",
    "system/fx/textures_zdr/trail_generic.bctex",
    "system/fx/textures_zdr/trail_noisy.bctex",
    "system/fx/textures_zdr/trailchareditor.bctex",
    "system/fx/textures_zdr/triangleglow03.bctex",
    "system/fx/textures_zdr/unihalo.bctex",
    "system/fx/textures_zdr/waterstream.bctex",
    "system/fx/textures_zdr/wave_big.bctex",
    "system/fx/textures_zdr/wave_vertical.bctex",
    "system/fx/textures_zdr/waves_morphball.bctex",
    "system/fx/textures_zdr/waves_noises_soft_02.bctex",
    "system/fx/textures_zdr/wavescloud_morphball.bctex",
    "system/fx/textures_zdr/wings_commander.bctex",
    "timelines/x_transformation/fx/textures/xparasitetransformation_bc.bctex",
]

dread_210_only = [
    "textures/gui/textures/bossrush/bossrush_bosses.bctex",
    "textures/gui/textures/bossrush/bossrush_samus_stats.bctex",
    "textures/gui/textures/bossrush/loading/def/01.bctex",
    "textures/gui/textures/bossrush/loading/def/02.bctex",
    "textures/gui/textures/bossrush/loading/def/03.bctex",
    "textures/gui/textures/bossrush/loading/def/04.bctex",
    "textures/gui/textures/bossrush/loading/def/05.bctex",
    "textures/gui/textures/bossrush/loading/def/06.bctex",
    "textures/gui/textures/bossrush/loading/def/07.bctex",
    "textures/gui/textures/bossrush/loading/def/08.bctex",
    "textures/gui/textures/bossrush/loading/def/09.bctex",
    "textures/gui/textures/bossrush/loading/def/10.bctex",
    "textures/gui/textures/bossrush/loading/def/11.bctex",
    "textures/gui/textures/bossrush/loading/def/12.bctex",
    "textures/gui/textures/bossrush/loading/dre/01.bctex",
    "textures/gui/textures/bossrush/loading/dre/02.bctex",
    "textures/gui/textures/bossrush/loading/dre/03.bctex",
    "textures/gui/textures/bossrush/loading/dre/04.bctex",
    "textures/gui/textures/bossrush/loading/dre/05.bctex",
    "textures/gui/textures/bossrush/loading/dre/06.bctex",
    "textures/gui/textures/bossrush/loading/dre/07.bctex",
    "textures/gui/textures/bossrush/loading/dre/08.bctex",
    "textures/gui/textures/bossrush/loading/dre/09.bctex",
    "textures/gui/textures/bossrush/loading/dre/10.bctex",
    "textures/gui/textures/bossrush/loading/dre/11.bctex",
    "textures/gui/textures/bossrush/loading/dre/12.bctex",
    "textures/gui/textures/bossrush/loading/pra/01.bctex",
    "textures/gui/textures/bossrush/loading/pra/02.bctex",
    "textures/gui/textures/bossrush/loading/pra/03.bctex",
    "textures/gui/textures/bossrush/loading/pra/04.bctex",
    "textures/gui/textures/bossrush/loading/pra/05.bctex",
    "textures/gui/textures/bossrush/loading/pra/06.bctex",
    "textures/gui/textures/bossrush/loading/pra/07.bctex",
    "textures/gui/textures/bossrush/loading/pra/08.bctex",
    "textures/gui/textures/bossrush/loading/pra/09.bctex",
    "textures/gui/textures/bossrush/loading/pra/10.bctex",
    "textures/gui/textures/bossrush/loading/pra/11.bctex",
    "textures/gui/textures/bossrush/loading/pra/12.bctex",
    "textures/gui/textures/bossrush/loading/prd/01.bctex",
    "textures/gui/textures/bossrush/loading/prd/02.bctex",
    "textures/gui/textures/bossrush/loading/prd/03.bctex",
    "textures/gui/textures/bossrush/loading/prd/04.bctex",
    "textures/gui/textures/bossrush/loading/prd/05.bctex",
    "textures/gui/textures/bossrush/loading/prd/06.bctex",
    "textures/gui/textures/bossrush/loading/prd/07.bctex",
    "textures/gui/textures/bossrush/loading/prd/08.bctex",
    "textures/gui/textures/bossrush/loading/prd/09.bctex",
    "textures/gui/textures/bossrush/loading/prd/10.bctex",
    "textures/gui/textures/bossrush/loading/prd/11.bctex",
    "textures/gui/textures/bossrush/loading/prd/12.bctex",
    "textures/gui/textures/bossrush/results_01.bctex",
    "textures/gui/textures/bossrush/results_02.bctex",
    "textures/gui/textures/difmode_dread.bctex",
    "textures/gui/textures/difmode_rookie.bctex",
]

sr_missing = [
    "actors/characters/alpha/models/textures/alphab_a.bctex",
    "actors/characters/alpha/models/textures/alphab_d.bctex",
    "actors/characters/alphacredits/models/textures/alphab_a.bctex",
    "actors/characters/alphacredits/models/textures/alphab_d.bctex",
    "actors/characters/gamma/models/textures/coreveins.bctex",
    "actors/characters/gammacredits/models/textures/coreveins.bctex",
    "actors/characters/gammaevolved/models/textures/coreveins.bctex",
    "actors/characters/glowflypuzzle/models/textures/glowfly_d.bctex",
    "actors/characters/metroid/models/textures/coreveins.bctex",
    "actors/characters/moheekwall/models/textures/moheekwall_a.bctex",
    "actors/characters/morphball/models/textures/fusionmorph_a.bctex",
    "actors/characters/morphball/models/textures/fusionmorphgravity_d.bctex",
    "actors/characters/morphball/models/textures/fusionmorphpower_d.bctex",
    "actors/characters/morphball/models/textures/fusionmorphvaria_d.bctex",
    "actors/characters/morphball/models/textures/samuspowermorphnew_a.bctex",
    "actors/characters/morphball/models/textures/samuspowermorphnew_d.bctex",
    "actors/characters/morphball/models/textures/samusvariamorph_a.bctex",
    "actors/characters/morphball/models/textures/samusvariamorph_d.bctex",
    "actors/characters/omega/models/textures/coreveins.bctex",
    "actors/characters/omegacredits/models/textures/coreveins.bctex",
    "actors/characters/omegaevolved/models/textures/coreveins.bctex",
    "actors/characters/queen/models/textures/coreveins.bctex",
    "actors/characters/queen/models/textures/queen01_a.bctex",
    "actors/characters/queen/models/textures/queen01_d.bctex",
    "actors/characters/queen/models/textures/queen02_a.bctex",
    "actors/characters/queen/models/textures/queen02_d.bctex",
    "actors/characters/queen/models/textures/queen03_a.bctex",
    "actors/characters/queen/models/textures/queen03_d.bctex",
    "actors/characters/queen/models/textures/queen04_a.bctex",
    "actors/characters/queen/models/textures/queen04_d.bctex",
    "actors/characters/ridley/models/textures/ridleydeath_d.bctex",
    "actors/characters/ridley/models/textures/ridleyhand_a.bctex",
    "actors/characters/ridley/models/textures/ridleyhand_d.bctex",
    "actors/characters/samus/models/textures/energywave.bctex",
    "actors/characters/samus/models/textures/gradientdif.bctex",
    "actors/characters/samus/models/textures/grid.bctex",
    "actors/characters/samus/models/textures/noise3.bctex",
    "actors/characters/samus/models/textures/samusending_a.bctex",
    "actors/characters/samus/models/textures/samusending_d.bctex",
    "actors/characters/samus/models/textures/samusgravityreward_d.bctex",
    "actors/characters/samus/models/textures/samusweaponreward_d.bctex",
    "actors/characters/samus/models/textures/samuszeroreward_a.bctex",
    "actors/characters/samus/models/textures/samuszeroreward_d.bctex",
    "actors/characters/samus/models/textures/samuszeroweapon_d.bctex",
    "actors/characters/samusfusion/models/textures/droppables00.bctex",
    "actors/characters/samusfusion/models/textures/droppables01.bctex",
    "actors/characters/samusfusion/models/textures/energywave.bctex",
    "actors/characters/samusfusion/models/textures/gradientdif.bctex",
    "actors/characters/samusfusion/models/textures/grid.bctex",
    "actors/characters/samusfusion/models/textures/laser_la.bctex",
    "actors/characters/samusfusion/models/textures/noise3.bctex",
    "actors/characters/samusfusion/models/textures/phasedisplacement.bctex",
    "actors/characters/samusfusion/models/textures/scanningpulse.bctex",
    "actors/characters/samusrewards/models/textures/energywave.bctex",
    "actors/characters/samusrewards/models/textures/gradientdif.bctex",
    "actors/characters/samusrewards/models/textures/grid.bctex",
    "actors/characters/samusrewards/models/textures/laser_la.bctex",
    "actors/characters/samusrewards/models/textures/noise3.bctex",
    "actors/characters/samusrewards/models/textures/phasedisplacement.bctex",
    "actors/characters/samusrewards/models/textures/samusending_a.bctex",
    "actors/characters/samusrewards/models/textures/samusending_d.bctex",
    "actors/characters/samusrewards/models/textures/samuspower_a.bctex",
    "actors/characters/samusrewards/models/textures/samuspower_d.bctex",
    "actors/characters/samusrewards/models/textures/samusvaria_a.bctex",
    "actors/characters/samusrewards/models/textures/samusvaria_d.bctex",
    "actors/characters/samusrewards/models/textures/samuszeroreward_a.bctex",
    "actors/characters/samusrewards/models/textures/samuszeroweapon_d.bctex",
    "actors/characters/samusrewards/models/textures/scanningpulse.bctex",
    "actors/characters/zeta/models/textures/coreveins.bctex",
    "actors/characters/zetacredits/models/textures/coreveins.bctex",
    "actors/characters/zetaevolved/models/textures/coreveins.bctex",
    "actors/items/itemsphere_spenergygaunlet/models/textures/itemspherespenergygaunlet_d.bctex",
    "actors/items/powerup_spinattack/models/textures/itemvariasuit_d.bctex",
    "actors/props/blockingplant/models/textures/blockingplantheavy_d.bctex",
    "actors/props/creditsfx/models/textures/glow_big.bctex",
    "actors/props/creditsfx/models/textures/glowmetroid.bctex",
    "actors/props/creditsfx/models/textures/halowind.bctex",
    "actors/props/creditsfx/models/textures/xflaremetroid.bctex",
    "actors/props/doorcreatureleft/models/textures/doorcreature_d.bctex",
    "actors/props/doorcreatureleft/models/textures/spiderweb_d.bctex",
    "actors/props/dropprop/models/textures/dropprop_d.bctex",
    "actors/props/samusshipinterior/models/textures/samusship_bigpanel2.bctex",
    "actors/props/spenergybestowalstatue/models/textures/spenergybestowalstatue_d.bctex",
    "actors/weapons/manicminerbotlaser/models/textures/target_circle.bctex",
    "actors/weapons/weaponstank/models/textures/tankglow.bctex",
    "actors/weapons/weaponstank/models/textures/weaponstank_d.bctex",
    "cutscenes/postcredits/models/xparasite/textures/cubemetroids.bctex",
    "maps/blocks/weightblock/textures/weightblock_d.bctex",
    "maps/objects/chozohologram/textures/chozohologram_d.bctex",
    "maps/textures/a1wall01.bctex",
    "maps/textures/a2chozocolumn0301_d.bctex",
    "maps/textures/a6chozocolumn01_d.bctex",
    "maps/textures/a6chozocolumn0204_d.bctex",
    "maps/textures/a9chozobg0301_d.bctex",
    "maps/textures/brick_wall00.bctex",
    "maps/textures/chozohologram01_d.bctex",
    "maps/textures/chozointeriortile04.bctex",
    "maps/textures/chozopath0902_d.bctex",
    "maps/textures/chozopath1002_d.bctex",
    "maps/textures/chozotilewall01b_d.bctex",
    "maps/textures/chozotilewall04haz_d.bctex",
    "maps/textures/chozoverticaldeco01_d.bctex",
    "maps/textures/clear_blue_checker.bctex",
    "maps/textures/dark_grey_checker.bctex",
    "maps/textures/debris0301_d.bctex",
    "maps/textures/green_d.bctex",
    "maps/textures/insect0702_d.bctex",
    "maps/textures/lava2.bctex",
    "maps/textures/light_grey_checker.bctex",
    "maps/textures/plant0103_d.bctex",
    "maps/textures/plant0607_d.bctex",
    "maps/textures/ref_rock03.bctex",
    "maps/textures/ref_rock05.bctex",
    "maps/textures/rock_wall01_d.bctex",
    "maps/textures/rock_wall02.bctex",
    "maps/textures/rockadorn0604cut_d.bctex",
    "maps/textures/rockadornchozo0303_d.bctex",
    "maps/textures/rockadornchozo0306_d.bctex",
    "maps/textures/rockadorngold0303_d.bctex",
    "maps/textures/rockadorngold0306_d.bctex",
    "maps/textures/rockbg0601.bctex",
    "maps/textures/rockcolumn0301_d.bctex",
    "maps/textures/rockcolumn04.bctex",
    "maps/textures/rockplatform0101_d.bctex",
    "maps/textures/rockplatform0405b_d.bctex",
    "maps/textures/rockplatform1002c_d.bctex",
    "maps/textures/rockwall0302_d.bctex",
    "maps/textures/rockwall0402b_d.bctex",
    "maps/textures/rockwalltile0604.bctex",
    "maps/textures/rockwalltile0702c_d.bctex",
    "maps/textures/sand02_d.bctex",
    "maps/textures/smoke0002_d.bctex",
    "maps/textures/spaceblackhole_d.bctex",
    "maps/textures/surface_sky.bctex",
    "maps/textures/surfacebray2c_d.bctex",
    "maps/textures/surfacecolumn01.bctex",
    "maps/textures/temp/cubemetroids.bctex",
    "maps/textures/wall06.bctex",
    "maps/textures/water10b_d.bctex",
    "maps/textures/waterfall.bctex",
    "maps/textures/waterfront01_d.bctex",
    "maps/textures/waterop.bctex",
    "system/fx/textures/arc.bctex",
    "system/fx/textures/arrow3.bctex",
    "system/fx/textures/ashes_la.bctex",
    "system/fx/textures/blood_red.bctex",
    "system/fx/textures/energy.bctex",
    "system/fx/textures/energybubble.bctex",
    "system/fx/textures/energyray.bctex",
    "system/fx/textures/energytrail.bctex",
    "system/fx/textures/fireball_l.bctex",
    "system/fx/textures/fireballbounce_l.bctex",
    "system/fx/textures/fireballbounce_rgba.bctex",
    "system/fx/textures/flame.bctex",
    "system/fx/textures/flameline.bctex",
    "system/fx/textures/fleechswarm.bctex",
    "system/fx/textures/laserfalloff_la.bctex",
    "system/fx/textures/lightning_fade.bctex",
    "system/fx/textures/lightningcore_l.bctex",
    "system/fx/textures/noise2.bctex",
    "system/fx/textures/ramp_bwbwb.bctex",
    "system/fx/textures/raypart_l.bctex",
    "system/fx/textures/specialab.bctex",
    "system/fx/textures/swarm.bctex",
    "system/fx/textures/swirl.bctex",
    "system/fx/textures/swirlcircle.bctex",
    "system/fx/textures/swirlexplosion.bctex",
    "system/fx/textures/target_l.bctex",
    "system/fx/textures/threadleak.bctex",
    "system/fx/textures/wind.bctex",
    "system/fx/textures/wind_arc.bctex",
]


@pytest.mark.parametrize(
    "bctex_path", dread_data.all_files_ending_with(".bctex", dread_210_ignore + dread_210_only + dread_exclusions)
)
def test_compare_bctex_dread_100(dread_tree_100, bctex_path):
    parse_build_compare_editor_parsed(Bctex, dread_tree_100, bctex_path)


@pytest.mark.parametrize("bctex_path", dread_210_only)
def test_compare_dread_210(dread_tree_210, bctex_path):
    parse_build_compare_editor_parsed(Bctex, dread_tree_210, bctex_path)


@pytest.mark.parametrize("bctex_path", samus_returns_data.all_files_ending_with(".bctex", sr_missing))
def test_compare_bctex_sr(samus_returns_tree, bctex_path):
    parse_build_compare_editor_parsed(Bctex, samus_returns_tree, bctex_path)
